(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.3' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    176169,       5197]
NotebookOptionsPosition[    168810,       5060]
NotebookOutlinePosition[    169272,       5079]
CellTagsIndexPosition[    169229,       5076]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["Supplementary Material for\n\
\[OpenCurlyDoubleQuote]Interfacial dynamics of confined liquid-vapour bilayer \
undergoing evaporation\[CloseCurlyDoubleQuote]\nby D.S. Pillai and R. \
Narayanan",
 FontSize->30]], "Chapter",
 TextAlignment->Center,ExpressionUUID->"76777feb-d6a4-4243-8fc3-5177d5598087"],

Cell[TextData[StyleBox["This Mathematica notebook contains the expression for \
the various variables and coefficients that appear in the main article.",
 FontFamily->"Arial"]], "Subsection",ExpressionUUID->"9a895c91-e008-4438-b3a5-\
eb47dd57c306"],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Leading order horizontal component of velocity for vapour phase (",
  FontFamily->"Arial"],
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    OverscriptBox["u", "^"], "v"], TraditionalForm]],ExpressionUUID->
  "68cf2d56-06c0-477c-ad48-919016ad6681"],
 StyleBox[") (Eq. 2.18)",
  FontFamily->"Arial"]
}], "Subsection",
 CellFrame->{{0, 0}, {
   0, 0.5}},ExpressionUUID->"68c09f61-8233-46f7-9e67-026523da3020"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"3", " ", 
       SuperscriptBox["z", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "3"}], " ", 
          SuperscriptBox[
           RowBox[{"h", "[", 
            RowBox[{"x", ",", "t"}], "]"}], "2"], " ", 
          RowBox[{
           SubscriptBox["q", "l"], "[", 
           RowBox[{"x", ",", "t"}], "]"}]}], "+", 
         RowBox[{"\[Mu]", " ", 
          RowBox[{
           SubscriptBox["q", "v"], "[", 
           RowBox[{"x", ",", "t"}], "]"}]}], "+", 
         RowBox[{"4", " ", 
          RowBox[{"h", "[", 
           RowBox[{"x", ",", "t"}], "]"}], " ", 
          RowBox[{
           SubscriptBox["q", "v"], "[", 
           RowBox[{"x", ",", "t"}], "]"}]}], "-", 
         RowBox[{"2", " ", "\[Mu]", " ", 
          RowBox[{"h", "[", 
           RowBox[{"x", ",", "t"}], "]"}], " ", 
          RowBox[{
           SubscriptBox["q", "v"], "[", 
           RowBox[{"x", ",", "t"}], "]"}]}], "-", 
         RowBox[{"4", " ", 
          SuperscriptBox[
           RowBox[{"h", "[", 
            RowBox[{"x", ",", "t"}], "]"}], "2"], " ", 
          RowBox[{
           SubscriptBox["q", "v"], "[", 
           RowBox[{"x", ",", "t"}], "]"}]}], "+", 
         RowBox[{"\[Mu]", " ", 
          SuperscriptBox[
           RowBox[{"h", "[", 
            RowBox[{"x", ",", "t"}], "]"}], "2"], " ", 
          RowBox[{
           SubscriptBox["q", "v"], "[", 
           RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"h", "[", 
          RowBox[{"x", ",", "t"}], "]"}]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"h", "[", 
         RowBox[{"x", ",", "t"}], "]"}], "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "\[Mu]"}], "-", 
         RowBox[{"h", "[", 
          RowBox[{"x", ",", "t"}], "]"}], "+", 
         RowBox[{"\[Mu]", " ", 
          RowBox[{"h", "[", 
           RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}]}], ")"}]}], ")"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"3", " ", "z", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox[
          RowBox[{"h", "[", 
           RowBox[{"x", ",", "t"}], "]"}], "2"]}], " ", 
        RowBox[{
         SubscriptBox["q", "l"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}], "+", 
       RowBox[{"\[Mu]", " ", 
        RowBox[{
         SubscriptBox["q", "v"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"h", "[", 
         RowBox[{"x", ",", "t"}], "]"}], " ", 
        RowBox[{
         SubscriptBox["q", "v"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}], "-", 
       RowBox[{"2", " ", "\[Mu]", " ", 
        RowBox[{"h", "[", 
         RowBox[{"x", ",", "t"}], "]"}], " ", 
        RowBox[{
         SubscriptBox["q", "v"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox[
         RowBox[{"h", "[", 
          RowBox[{"x", ",", "t"}], "]"}], "2"], " ", 
        RowBox[{
         SubscriptBox["q", "v"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}], "+", 
       RowBox[{"\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{"h", "[", 
          RowBox[{"x", ",", "t"}], "]"}], "2"], " ", 
        RowBox[{
         SubscriptBox["q", "v"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"h", "[", 
        RowBox[{"x", ",", "t"}], "]"}]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"h", "[", 
       RowBox[{"x", ",", "t"}], "]"}], "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "\[Mu]"}], "-", 
       RowBox[{"h", "[", 
        RowBox[{"x", ",", "t"}], "]"}], "+", 
       RowBox[{"\[Mu]", " ", 
        RowBox[{"h", "[", 
         RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}]}], ")"}]}]}]], "Output",Exp\
ressionUUID->"9ce02677-ff42-4a38-94ad-2f12b9e314ec"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Leading order horizontal component of velocity for liquid phase (",
  FontFamily->"Arial"],
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    OverscriptBox["u", "^"], "l"], TraditionalForm]],ExpressionUUID->
  "e5550d81-6ecf-4c1f-a632-471ad5751758"],
 StyleBox[") (Eq. 2.18)",
  FontFamily->"Arial"]
}], "Subsection",
 CellFrame->{{0, 0}, {
   0, 0.5}},ExpressionUUID->"de5d189b-2499-4e19-8092-7297255a24f8"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{"3", " ", 
     SuperscriptBox["z", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "4"}], " ", "\[Mu]", " ", 
        RowBox[{"h", "[", 
         RowBox[{"x", ",", "t"}], "]"}], " ", 
        RowBox[{
         SubscriptBox["q", "l"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}], "-", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"h", "[", 
          RowBox[{"x", ",", "t"}], "]"}], "2"], " ", 
        RowBox[{
         SubscriptBox["q", "l"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}], "+", 
       RowBox[{"4", " ", "\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{"h", "[", 
          RowBox[{"x", ",", "t"}], "]"}], "2"], " ", 
        RowBox[{
         SubscriptBox["q", "l"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}], "+", 
       RowBox[{"3", " ", "\[Mu]", " ", 
        RowBox[{
         SubscriptBox["q", "v"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}], "-", 
       RowBox[{"6", " ", "\[Mu]", " ", 
        RowBox[{"h", "[", 
         RowBox[{"x", ",", "t"}], "]"}], " ", 
        RowBox[{
         SubscriptBox["q", "v"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}], "+", 
       RowBox[{"3", " ", "\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{"h", "[", 
          RowBox[{"x", ",", "t"}], "]"}], "2"], " ", 
        RowBox[{
         SubscriptBox["q", "v"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"2", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"h", "[", 
         RowBox[{"x", ",", "t"}], "]"}]}], ")"}], "3"], " ", 
     RowBox[{"h", "[", 
      RowBox[{"x", ",", "t"}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "\[Mu]"}], "-", 
       RowBox[{"h", "[", 
        RowBox[{"x", ",", "t"}], "]"}], "+", 
       RowBox[{"\[Mu]", " ", 
        RowBox[{"h", "[", 
         RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}]}], ")"}]}], "-", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"3", " ", "z", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", "\[Mu]", " ", 
        RowBox[{"h", "[", 
         RowBox[{"x", ",", "t"}], "]"}], " ", 
        RowBox[{
         SubscriptBox["q", "l"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}], "-", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"h", "[", 
          RowBox[{"x", ",", "t"}], "]"}], "3"], " ", 
        RowBox[{
         SubscriptBox["q", "l"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}], "+", 
       RowBox[{"2", " ", "\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{"h", "[", 
          RowBox[{"x", ",", "t"}], "]"}], "3"], " ", 
        RowBox[{
         SubscriptBox["q", "l"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}], "+", 
       RowBox[{"2", " ", "\[Mu]", " ", 
        RowBox[{
         SubscriptBox["q", "v"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}], "-", 
       RowBox[{"3", " ", "\[Mu]", " ", 
        RowBox[{"h", "[", 
         RowBox[{"x", ",", "t"}], "]"}], " ", 
        RowBox[{
         SubscriptBox["q", "v"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}], "+", 
       RowBox[{"\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{"h", "[", 
          RowBox[{"x", ",", "t"}], "]"}], "3"], " ", 
        RowBox[{
         SubscriptBox["q", "v"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"h", "[", 
         RowBox[{"x", ",", "t"}], "]"}]}], ")"}], "3"], " ", 
     RowBox[{"h", "[", 
      RowBox[{"x", ",", "t"}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "\[Mu]"}], "-", 
       RowBox[{"h", "[", 
        RowBox[{"x", ",", "t"}], "]"}], "+", 
       RowBox[{"\[Mu]", " ", 
        RowBox[{"h", "[", 
         RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}]}], ")"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"3", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"h", "[", 
          RowBox[{"x", ",", "t"}], "]"}], "2"], " ", 
        RowBox[{
         SubscriptBox["q", "l"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}], "-", 
       RowBox[{"4", " ", "\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{"h", "[", 
          RowBox[{"x", ",", "t"}], "]"}], "2"], " ", 
        RowBox[{
         SubscriptBox["q", "l"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox[
         RowBox[{"h", "[", 
          RowBox[{"x", ",", "t"}], "]"}], "3"], " ", 
        RowBox[{
         SubscriptBox["q", "l"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}], "+", 
       RowBox[{"4", " ", "\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{"h", "[", 
          RowBox[{"x", ",", "t"}], "]"}], "3"], " ", 
        RowBox[{
         SubscriptBox["q", "l"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}], "+", 
       RowBox[{"\[Mu]", " ", 
        RowBox[{
         SubscriptBox["q", "v"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}], "-", 
       RowBox[{"3", " ", "\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{"h", "[", 
          RowBox[{"x", ",", "t"}], "]"}], "2"], " ", 
        RowBox[{
         SubscriptBox["q", "v"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}], "+", 
       RowBox[{"2", " ", "\[Mu]", " ", 
        SuperscriptBox[
         RowBox[{"h", "[", 
          RowBox[{"x", ",", "t"}], "]"}], "3"], " ", 
        RowBox[{
         SubscriptBox["q", "v"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}]}], ")"}], "/", 
   RowBox[{"(", 
    RowBox[{"2", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"h", "[", 
         RowBox[{"x", ",", "t"}], "]"}]}], ")"}], "3"], " ", 
     RowBox[{"h", "[", 
      RowBox[{"x", ",", "t"}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "\[Mu]"}], "-", 
       RowBox[{"h", "[", 
        RowBox[{"x", ",", "t"}], "]"}], "+", 
       RowBox[{"\[Mu]", " ", 
        RowBox[{"h", "[", 
         RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}]}], ")"}]}]}]], "Output",Exp\
ressionUUID->"d9f3610c-d1cf-4b96-944b-b77795f721d7"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Velocity weight function, ",
  FontFamily->"Arial"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    SubscriptBox["F", "v"], 
    RowBox[{"(", "+", ")"}]], TraditionalForm]],ExpressionUUID->
  "0c3914b4-060a-4d3b-85af-1f6925821226"],
 ",",
 StyleBox[" (as defined by 2.22),",
  FontFamily->"Arial"]
}], "Subsection",
 CellFrame->{{0, 0}, {
   0, 0.5}},ExpressionUUID->"d85df040-6907-48d7-ba53-881939363ceb"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   SuperscriptBox["z", "2"], "2"], "-", 
  FractionBox[
   RowBox[{"z", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"h", "[", 
        RowBox[{"x", ",", "t"}], "]"}]}], "-", 
      RowBox[{"2", " ", "\[Mu]", " ", 
       RowBox[{"h", "[", 
        RowBox[{"x", ",", "t"}], "]"}]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{"h", "[", 
         RowBox[{"x", ",", "t"}], "]"}], "2"]}], "+", 
      RowBox[{"2", " ", "\[Mu]", " ", 
       SuperscriptBox[
        RowBox[{"h", "[", 
         RowBox[{"x", ",", "t"}], "]"}], "2"]}]}], ")"}]}], 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "\[Mu]"}], "-", 
      RowBox[{"h", "[", 
       RowBox[{"x", ",", "t"}], "]"}], "+", 
      RowBox[{"\[Mu]", " ", 
       RowBox[{"h", "[", 
        RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}]}]]}]], "Output",ExpressionUU\
ID->"34990140-33d0-478e-971e-15b9b875e135"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Velocity weight function, ",
  FontFamily->"Arial"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    SubscriptBox["F", "l"], 
    RowBox[{"(", "+", ")"}]], TraditionalForm]],ExpressionUUID->
  "7dfdd174-0e68-40c2-bba4-9fd4a58788a6"],
 ",",
 StyleBox[" (as defined by 2.22)",
  FontFamily->"Arial"]
}], "Subsection",
 CellFrame->{{0, 0}, {
   0, 0.5}},ExpressionUUID->"d204a984-97d0-4949-a9e4-ca5226e36acf"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   SuperscriptBox["z", "2"], "2"], "-", 
  FractionBox[
   RowBox[{
    RowBox[{"-", 
     RowBox[{"h", "[", 
      RowBox[{"x", ",", "t"}], "]"}]}], "+", 
    RowBox[{"\[Mu]", " ", 
     RowBox[{"h", "[", 
      RowBox[{"x", ",", "t"}], "]"}]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox[
      RowBox[{"h", "[", 
       RowBox[{"x", ",", "t"}], "]"}], "2"]}], "-", 
    RowBox[{"2", " ", "\[Mu]", " ", 
     SuperscriptBox[
      RowBox[{"h", "[", 
       RowBox[{"x", ",", "t"}], "]"}], "2"]}]}], 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "\[Mu]"}], "-", 
      RowBox[{"h", "[", 
       RowBox[{"x", ",", "t"}], "]"}], "+", 
      RowBox[{"\[Mu]", " ", 
       RowBox[{"h", "[", 
        RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{"z", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "\[Mu]"}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{"h", "[", 
         RowBox[{"x", ",", "t"}], "]"}], "2"]}], "+", 
      RowBox[{"2", " ", "\[Mu]", " ", 
       SuperscriptBox[
        RowBox[{"h", "[", 
         RowBox[{"x", ",", "t"}], "]"}], "2"]}]}], ")"}]}], 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "\[Mu]"}], "-", 
      RowBox[{"h", "[", 
       RowBox[{"x", ",", "t"}], "]"}], "+", 
      RowBox[{"\[Mu]", " ", 
       RowBox[{"h", "[", 
        RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}]}]]}]], "Output",ExpressionUU\
ID->"57420244-b119-4e35-afa7-2ca7b3938777"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    SubscriptBox["I", "v"], 
    RowBox[{"(", "+", ")"}]], TraditionalForm]],ExpressionUUID->
  "d8be4592-d80b-4015-8b07-15b254b63588"],
 StyleBox[" that appears in (2.24)",
  FontFamily->"Arial"]
}], "Subsection",
 CellFrame->{{0, 0}, {
   0, 0.5}},ExpressionUUID->"4f7de890-0f87-4f4c-9d15-2e0a6776d6f8"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox[
    RowBox[{"h", "[", 
     RowBox[{"x", ",", "t"}], "]"}], "2"], " ", 
   RowBox[{"(", 
    RowBox[{"3", "+", 
     RowBox[{"2", " ", 
      RowBox[{"h", "[", 
       RowBox[{"x", ",", "t"}], "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3"}], "+", 
        RowBox[{"2", " ", "\[Mu]"}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "\[Mu]"}], ")"}], " ", 
         RowBox[{"h", "[", 
          RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}]}]}], ")"}]}], 
  RowBox[{
   RowBox[{
    RowBox[{"-", "12"}], " ", "\[Mu]"}], "+", 
   RowBox[{"12", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "\[Mu]"}], ")"}], " ", 
    RowBox[{"h", "[", 
     RowBox[{"x", ",", "t"}], "]"}]}]}]]], "Output",ExpressionUUID->"7bfb2096-\
f4ea-48ba-9493-a4cf65ce6483"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    SubscriptBox["I", "l"], 
    RowBox[{"(", "+", ")"}]], TraditionalForm]],ExpressionUUID->
  "4b128244-7e98-463a-a893-e92236efb5b3"],
 StyleBox[" that appears in (2.24)",
  FontFamily->"Arial"]
}], "Subsection",
 CellFrame->{{0, 0}, {
   0, 0.5}},ExpressionUUID->"7aa7a771-7bad-4419-af48-b2ef31a698b2"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"h", "[", 
       RowBox[{"x", ",", "t"}], "]"}]}], ")"}], "2"], " ", 
   RowBox[{"(", 
    RowBox[{"\[Mu]", "-", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "2"}], "+", "\[Mu]"}], ")"}], " ", 
      RowBox[{"h", "[", 
       RowBox[{"x", ",", "t"}], "]"}]}], "+", 
     RowBox[{"4", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "\[Mu]"}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"h", "[", 
        RowBox[{"x", ",", "t"}], "]"}], "2"]}]}], ")"}]}], 
  RowBox[{"12", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "\[Mu]"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "\[Mu]"}], ")"}], " ", 
      RowBox[{"h", "[", 
       RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}]}]]], "Output",ExpressionUUID-\
>"6025b525-fcf9-435f-abe2-668dcd6751bc"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Velocity weight function, ",
  FontFamily->"Arial"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    SubscriptBox["F", "v"], 
    RowBox[{"(", "-", ")"}]], TraditionalForm]],ExpressionUUID->
  "dd0b29d6-36e8-49e1-9218-63684603a8cc"],
 ",",
 StyleBox[" (as defined by 2.22)",
  FontFamily->"Arial"]
}], "Subsection",
 CellFrame->{{0, 0}, {
   0, 0.5}},ExpressionUUID->"d4407e63-658e-42f5-ae3d-bf117496b394"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   SuperscriptBox["z", "2"], "2"], "-", 
  FractionBox[
   RowBox[{"z", " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      RowBox[{"2", " ", 
       RowBox[{"h", "[", 
        RowBox[{"x", ",", "t"}], "]"}]}], "-", 
      RowBox[{"2", " ", "\[Mu]", " ", 
       RowBox[{"h", "[", 
        RowBox[{"x", ",", "t"}], "]"}]}], "+", 
      RowBox[{"2", " ", "\[Mu]", " ", 
       SuperscriptBox[
        RowBox[{"h", "[", 
         RowBox[{"x", ",", "t"}], "]"}], "2"]}]}], ")"}]}], 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "\[Mu]"}], "-", 
      RowBox[{"h", "[", 
       RowBox[{"x", ",", "t"}], "]"}], "+", 
      RowBox[{"\[Mu]", " ", 
       RowBox[{"h", "[", 
        RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}]}]]}]], "Output",ExpressionUU\
ID->"6de8cb7c-3c28-4868-b993-b3cefc59e5f9"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Velocity weight function, ",
  FontFamily->"Arial"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    SubscriptBox["F", "l"], 
    RowBox[{"(", "-", ")"}]], TraditionalForm]],ExpressionUUID->
  "15fd3e8d-766c-4fea-aca5-99928cf6ff9d"],
 ",",
 StyleBox[" (as defined by 2.22)",
  FontFamily->"Arial"]
}], "Subsection",
 CellFrame->{{0, 0}, {
   0, 0.5}},ExpressionUUID->"cb600586-8e4d-4aec-b1be-e4c3de119293"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    SuperscriptBox["z", "2"], "2"]}], "-", 
  FractionBox[
   RowBox[{
    RowBox[{"h", "[", 
     RowBox[{"x", ",", "t"}], "]"}], "-", 
    RowBox[{"\[Mu]", " ", 
     RowBox[{"h", "[", 
      RowBox[{"x", ",", "t"}], "]"}]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox[
      RowBox[{"h", "[", 
       RowBox[{"x", ",", "t"}], "]"}], "2"]}]}], 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "\[Mu]"}], "-", 
      RowBox[{"h", "[", 
       RowBox[{"x", ",", "t"}], "]"}], "+", 
      RowBox[{"\[Mu]", " ", 
       RowBox[{"h", "[", 
        RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{"z", " ", 
    RowBox[{"(", 
     RowBox[{"\[Mu]", "+", 
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{"h", "[", 
         RowBox[{"x", ",", "t"}], "]"}], "2"]}]}], ")"}]}], 
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "\[Mu]"}], "-", 
      RowBox[{"h", "[", 
       RowBox[{"x", ",", "t"}], "]"}], "+", 
      RowBox[{"\[Mu]", " ", 
       RowBox[{"h", "[", 
        RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}]}]]}]], "Output",ExpressionUU\
ID->"04a83d58-7bb8-4845-af7f-581ab47f27ca"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    SubscriptBox["I", "v"], 
    RowBox[{"(", "-", ")"}]], TraditionalForm]],ExpressionUUID->
  "6564bc81-8003-4f94-a08a-f752247eec9b"],
 StyleBox[" that appears in (2.24)",
  FontFamily->"Arial"]
}], "Subsection",
 CellFrame->{{0, 0}, {
   0, 0.5}},ExpressionUUID->"7ab022b9-f037-4754-9185-c19362cac0b2"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "6"], " ", 
  SuperscriptBox[
   RowBox[{"h", "[", 
    RowBox[{"x", ",", "t"}], "]"}], "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"h", "[", 
     RowBox[{"x", ",", "t"}], "]"}], "+", 
    FractionBox[
     RowBox[{"6", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"h", "[", 
          RowBox[{"x", ",", "t"}], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", "\[Mu]", "-", 
           RowBox[{"\[Mu]", " ", 
            RowBox[{"h", "[", 
             RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}]}]}], ")"}]}], 
     RowBox[{
      RowBox[{
       RowBox[{"-", "4"}], " ", "\[Mu]"}], "+", 
      RowBox[{"4", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[Mu]"}], ")"}], " ", 
       RowBox[{"h", "[", 
        RowBox[{"x", ",", "t"}], "]"}]}]}]]}], ")"}]}]], "Output",ExpressionUU\
ID->"d1ee7812-a2d5-469e-a4a0-9f6e7492b909"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    SubscriptBox["I", "l"], 
    RowBox[{"(", "-", ")"}]], TraditionalForm]],ExpressionUUID->
  "a9f9eb07-e9a7-4e15-a146-7f25cf0b8bf8"],
 StyleBox[" that appears in (2.24)",
  FontFamily->"Arial"]
}], "Subsection",
 CellFrame->{{0, 0}, {
   0, 0.5}},ExpressionUUID->"40c081c1-dfc4-4fd6-9992-1c57bda31112"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"h", "[", 
       RowBox[{"x", ",", "t"}], "]"}]}], ")"}], "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "\[Mu]"}], "+", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "2"}], "+", "\[Mu]"}], ")"}], " ", 
      RowBox[{"h", "[", 
       RowBox[{"x", ",", "t"}], "]"}]}], "+", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"2", "+", "\[Mu]"}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"h", "[", 
        RowBox[{"x", ",", "t"}], "]"}], "2"]}]}], ")"}]}], 
  RowBox[{"12", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "\[Mu]"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "\[Mu]"}], ")"}], " ", 
      RowBox[{"h", "[", 
       RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}]}]]], "Output",ExpressionUUID-\
>"f8c06807-fb8c-49cf-94c2-3ad98a4c91f9"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Leading order vapour temperature profile, ",
  FontFamily->"Arial"],
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    OverscriptBox["T", "^"], "v"], TraditionalForm]],ExpressionUUID->
  "570f0ca3-caf8-41d4-96d0-aa9ec971ba51"],
 StyleBox[", (eq. 2.20)",
  FontFamily->"Arial"]
}], "Subsection",
 CellFrame->{{0, 0}, {
   0, 0.5}},ExpressionUUID->"44f398ad-97e1-414d-a16c-092489e95714"],

Cell[BoxData[
 RowBox[{"1", "-", 
  FractionBox[
   RowBox[{"z", " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      RowBox[{"\[Theta]", "[", 
       RowBox[{"x", ",", "t"}], "]"}]}], ")"}]}], 
   RowBox[{"h", "[", 
    RowBox[{"x", ",", "t"}], "]"}]]}]], "Output",ExpressionUUID->"92b8cce3-\
c492-4764-bf1c-3a4167de4ac9"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Leading order liquid temperature profile, ",
  FontFamily->"Arial"],
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    OverscriptBox["T", "^"], "l"], TraditionalForm]],ExpressionUUID->
  "36a19c57-e16b-43a8-bafc-63d6e36b4cf8"],
 StyleBox[", (eq. 2.20)",
  FontFamily->"Arial"]
}], "Subsection",
 CellFrame->{{0, 0}, {
   0, 0.5}},ExpressionUUID->"ff2a021e-b3c4-4554-a299-bb37d718202a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{"\[Theta]", "[", 
     RowBox[{"x", ",", "t"}], "]"}], 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     RowBox[{"h", "[", 
      RowBox[{"x", ",", "t"}], "]"}]}]]}], "+", 
  FractionBox[
   RowBox[{"z", " ", 
    RowBox[{"\[Theta]", "[", 
     RowBox[{"x", ",", "t"}], "]"}]}], 
   RowBox[{
    RowBox[{"-", "1"}], "+", 
    RowBox[{"h", "[", 
     RowBox[{"x", ",", "t"}], "]"}]}]]}]], "Output",ExpressionUUID->"797b8807-\
7bdc-436c-acb8-733760d6db12"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Temperature weight function, ",
  FontFamily->"Arial"],
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    OverscriptBox["F", "^"], "v"], TraditionalForm]],ExpressionUUID->
  "68d1f9ab-6fa9-43f7-ae4b-11c383b5c3f9"],
 StyleBox[", (eq. 2.23)",
  FontFamily->"Arial"]
}], "Subsection",
 CellFrame->{{0, 0}, {
   0, 0.5}},ExpressionUUID->"227dbb67-cf59-4e98-8728-ab305bd1c2cc"],

Cell[BoxData["z"], "Output",ExpressionUUID->"2b3f8789-22dd-4151-bbf9-5d1f2daa115e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Temperature weight function, ",
  FontFamily->"Arial"],
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    OverscriptBox["F", "^"], "l"], TraditionalForm]],ExpressionUUID->
  "78f271da-abdf-4683-a362-b4364ac5f521"],
 StyleBox[", (eq. 2.23)",
  FontFamily->"Arial"]
}], "Subsection",
 CellFrame->{{0, 0}, {
   0, 0.5}},ExpressionUUID->"4fc977b0-d3c8-492e-9b6c-8d4c20980a0f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{"h", "[", 
     RowBox[{"x", ",", "t"}], "]"}], 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     RowBox[{"h", "[", 
      RowBox[{"x", ",", "t"}], "]"}]}]]}], "+", 
  FractionBox[
   RowBox[{"z", " ", 
    RowBox[{"h", "[", 
     RowBox[{"x", ",", "t"}], "]"}]}], 
   RowBox[{
    RowBox[{"-", "1"}], "+", 
    RowBox[{"h", "[", 
     RowBox[{"x", ",", "t"}], "]"}]}]]}]], "Output",ExpressionUUID->"d90c9a31-\
1b3c-4791-a245-f1da288ef42f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["In 2.24(b), ",
  FontFamily->"Arial",
  FontColor->RGBColor[1, 0, 0]],
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "1"], TraditionalForm]],
  FontFamily->"Arial",
  FontColor->RGBColor[1, 0, 0],ExpressionUUID->
  "8f56bc8c-1178-4c36-b37b-1f1e8519a9fa"],
 StyleBox[" is given by",
  FontFamily->"Arial",
  FontColor->RGBColor[1, 0, 0]]
}], "Subsection",
 CellFrame->{{0, 0}, {
   0, 0.5}},ExpressionUUID->"d3908f0f-f7e4-4f84-9c4c-10789e1d1a2b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"8", " ", 
     SuperscriptBox["\[Mu]", "2"]}], "-", 
    RowBox[{"5", " ", "\[Mu]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "7"}], "+", 
       RowBox[{"8", " ", "\[Mu]"}]}], ")"}], " ", 
     RowBox[{"h", "[", 
      RowBox[{"x", ",", "t"}], "]"}]}], "+", 
    RowBox[{"4", " ", 
     RowBox[{"(", 
      RowBox[{"8", "-", 
       RowBox[{"35", " ", "\[Mu]"}], "+", 
       RowBox[{"25", " ", 
        SuperscriptBox["\[Mu]", "2"]}]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"h", "[", 
       RowBox[{"x", ",", "t"}], "]"}], "2"]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "96"}], "+", 
       RowBox[{"235", " ", "\[Mu]"}], "-", 
       RowBox[{"140", " ", 
        SuperscriptBox["\[Mu]", "2"]}], "+", 
       RowBox[{"5", " ", "\[Rho]"}]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"h", "[", 
       RowBox[{"x", ",", "t"}], "]"}], "3"]}], "+", 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{"48", "+", 
       RowBox[{"50", " ", 
        SuperscriptBox["\[Mu]", "2"]}], "-", 
       RowBox[{"5", " ", "\[Rho]"}], "+", 
       RowBox[{"\[Mu]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "95"}], "+", 
          RowBox[{"2", " ", "\[Rho]"}]}], ")"}]}]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"h", "[", 
       RowBox[{"x", ",", "t"}], "]"}], "4"]}], "-", 
    RowBox[{"4", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "\[Mu]"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "8"}], "+", 
       RowBox[{"7", " ", "\[Mu]"}], "+", "\[Rho]"}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"h", "[", 
       RowBox[{"x", ",", "t"}], "]"}], "5"]}]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"80", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"h", "[", 
       RowBox[{"x", ",", "t"}], "]"}]}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"\[Mu]", "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[Mu]"}], ")"}], " ", 
        RowBox[{"h", "[", 
         RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}], "2"]}], ")"}]}]], "Output",\
ExpressionUUID->"236becdf-1c63-48f0-a625-65499fc7cf74"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["In 2.24(b), ",
  FontFamily->"Arial",
  FontColor->RGBColor[1, 0, 0]],
 Cell[BoxData[
  FormBox[
   SubscriptBox["L", "2"], TraditionalForm]],
  FontFamily->"Arial",
  FontColor->RGBColor[1, 0, 0],ExpressionUUID->
  "a311b7c5-cf16-478b-b24a-21384f4d1166"],
 StyleBox[" is given by",
  FontFamily->"Arial",
  FontColor->RGBColor[1, 0, 0]]
}], "Subsection",
 CellFrame->{{0, 0}, {
   0, 0.5}},ExpressionUUID->"10249f40-872c-408c-8ec7-41b6c2c12ffe"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "7"}], " ", 
     SuperscriptBox["\[Mu]", "3"], " ", 
     RowBox[{
      SubscriptBox["q", "v"], "[", 
      RowBox[{"x", ",", "t"}], "]"}]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["\[Mu]", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"7", "-", 
       RowBox[{"37", " ", "\[Mu]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[Rho]"}], ")"}]}]}], ")"}], " ", 
     RowBox[{"h", "[", 
      RowBox[{"x", ",", "t"}], "]"}], " ", 
     RowBox[{
      SubscriptBox["q", "v"], "[", 
      RowBox[{"x", ",", "t"}], "]"}]}], "+", 
    RowBox[{"\[Mu]", " ", 
     SuperscriptBox[
      RowBox[{"h", "[", 
       RowBox[{"x", ",", "t"}], "]"}], "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Mu]", " ", 
        RowBox[{"(", 
         RowBox[{"7", "+", 
          RowBox[{"4", " ", "\[Mu]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "34"}], "+", 
             RowBox[{"27", " ", "\[Rho]"}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{
         SubscriptBox["q", "l"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"56", "+", 
          RowBox[{"7", " ", 
           SuperscriptBox["\[Mu]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "41"}], "+", 
             RowBox[{"74", " ", "\[Rho]"}]}], ")"}]}], "-", 
          RowBox[{"\[Mu]", " ", 
           RowBox[{"(", 
            RowBox[{"65", "+", 
             RowBox[{"257", " ", "\[Rho]"}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{
         SubscriptBox["q", "v"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}]}], "-", 
    RowBox[{"2", " ", "\[Mu]", " ", 
     SuperscriptBox[
      RowBox[{"h", "[", 
       RowBox[{"x", ",", "t"}], "]"}], "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{"7", "+", 
          RowBox[{"\[Mu]", " ", 
           RowBox[{"(", 
            RowBox[{"184", "-", 
             RowBox[{"177", " ", "\[Rho]"}]}], ")"}]}], "+", 
          RowBox[{"6", " ", 
           SuperscriptBox["\[Mu]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "34"}], "+", 
             RowBox[{"27", " ", "\[Rho]"}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{
         SubscriptBox["q", "l"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"206", "+", 
          RowBox[{"81", " ", "\[Rho]"}], "+", 
          RowBox[{"7", " ", 
           SuperscriptBox["\[Mu]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "42"}], "+", 
             RowBox[{"115", " ", "\[Rho]"}]}], ")"}]}], "-", 
          RowBox[{"\[Mu]", " ", 
           RowBox[{"(", 
            RowBox[{"83", "+", 
             RowBox[{"771", " ", "\[Rho]"}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{
         SubscriptBox["q", "v"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}]}], "+", 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "\[Mu]"}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"h", "[", 
       RowBox[{"x", ",", "t"}], "]"}], "8"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "272"}], "+", 
          RowBox[{"\[Mu]", " ", 
           RowBox[{"(", 
            RowBox[{"433", "-", 
             RowBox[{"545", " ", "\[Rho]"}]}], ")"}]}], "+", 
          RowBox[{"403", " ", "\[Rho]"}], "-", 
          RowBox[{"75", " ", 
           SuperscriptBox["\[Rho]", "2"]}], "+", 
          RowBox[{"4", " ", 
           SuperscriptBox["\[Mu]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "59"}], "+", 
             RowBox[{"73", " ", "\[Rho]"}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{
         SubscriptBox["q", "l"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{"43", "-", 
             RowBox[{"15", " ", "\[Rho]"}]}], ")"}], " ", "\[Rho]"}], "+", 
          RowBox[{
           SuperscriptBox["\[Mu]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "9"}], "+", 
             RowBox[{"65", " ", "\[Rho]"}]}], ")"}]}], "-", 
          RowBox[{"\[Mu]", " ", 
           RowBox[{"(", 
            RowBox[{"66", "+", "\[Rho]", "+", 
             RowBox[{"45", " ", 
              SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{
         SubscriptBox["q", "v"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}]}], "+", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"h", "[", 
       RowBox[{"x", ",", "t"}], "]"}], "4"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Mu]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "871"}], "-", 
          RowBox[{"3540", " ", "\[Mu]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "\[Rho]"}], ")"}]}], "+", 
          RowBox[{"1011", " ", "\[Rho]"}], "+", 
          RowBox[{"8", " ", 
           SuperscriptBox["\[Mu]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "297"}], "+", 
             RowBox[{"262", " ", "\[Rho]"}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{
         SubscriptBox["q", "l"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "140"}], " ", "\[Rho]"}], "+", 
          RowBox[{"35", " ", 
           SuperscriptBox["\[Mu]", "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "21"}], "+", 
             RowBox[{"82", " ", "\[Rho]"}]}], ")"}]}], "-", 
          RowBox[{"24", " ", 
           SuperscriptBox["\[Mu]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"17", "+", 
             RowBox[{"158", " ", "\[Rho]"}]}], ")"}]}], "+", 
          RowBox[{"\[Mu]", " ", 
           RowBox[{"(", 
            RowBox[{"1220", "+", 
             RowBox[{"761", " ", "\[Rho]"}], "+", 
             RowBox[{"84", " ", 
              SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{
         SubscriptBox["q", "v"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox[
      RowBox[{"h", "[", 
       RowBox[{"x", ",", "t"}], "]"}], "7"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox["\[Mu]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"2694", "-", 
             RowBox[{"3191", " ", "\[Rho]"}]}], ")"}]}], "+", 
          RowBox[{"4", " ", 
           SuperscriptBox["\[Mu]", "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "270"}], "+", 
             RowBox[{"319", " ", "\[Rho]"}]}], ")"}]}], "+", 
          RowBox[{"\[Mu]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2379"}], "+", 
             RowBox[{"2860", " ", "\[Rho]"}], "-", 
             RowBox[{"75", " ", 
              SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}], "+", 
          RowBox[{"3", " ", 
           RowBox[{"(", 
            RowBox[{"272", "-", 
             RowBox[{"349", " ", "\[Rho]"}], "+", 
             RowBox[{"42", " ", 
              SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{
         SubscriptBox["q", "l"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"36", " ", "\[Rho]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "9"}], "+", 
             RowBox[{"2", " ", "\[Rho]"}]}], ")"}]}], "+", 
          RowBox[{"7", " ", 
           SuperscriptBox["\[Mu]", "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "8"}], "+", 
             RowBox[{"57", " ", "\[Rho]"}]}], ")"}]}], "+", 
          RowBox[{"\[Mu]", " ", 
           RowBox[{"(", 
            RowBox[{"358", "+", 
             RowBox[{"375", " ", "\[Rho]"}], "+", 
             RowBox[{"114", " ", 
              SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}], "-", 
          RowBox[{
           SuperscriptBox["\[Mu]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"251", "+", 
             RowBox[{"552", " ", "\[Rho]"}], "+", 
             RowBox[{"135", " ", 
              SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{
         SubscriptBox["q", "v"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox[
      RowBox[{"h", "[", 
       RowBox[{"x", ",", "t"}], "]"}], "5"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"272", "+", 
          RowBox[{
           SuperscriptBox["\[Mu]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"3806", "-", 
             RowBox[{"3995", " ", "\[Rho]"}]}], ")"}]}], "+", 
          RowBox[{"2032", " ", 
           SuperscriptBox["\[Mu]", "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "\[Rho]"}], ")"}]}], "-", 
          RowBox[{"286", " ", "\[Rho]"}], "+", 
          RowBox[{"\[Mu]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1882"}], "+", 
             RowBox[{"2057", " ", "\[Rho]"}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{
         SubscriptBox["q", "l"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"7", " ", "\[Rho]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "43"}], "+", 
             RowBox[{"3", " ", "\[Rho]"}]}], ")"}]}], "+", 
          RowBox[{"7", " ", 
           SuperscriptBox["\[Mu]", "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "43"}], "+", 
             RowBox[{"225", " ", "\[Rho]"}]}], ")"}]}], "-", 
          RowBox[{
           SuperscriptBox["\[Mu]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"391", "+", 
             RowBox[{"2413", " ", "\[Rho]"}], "+", 
             RowBox[{"45", " ", 
              SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}], "+", 
          RowBox[{"\[Mu]", " ", 
           RowBox[{"(", 
            RowBox[{"940", "+", 
             RowBox[{"719", " ", "\[Rho]"}], "+", 
             RowBox[{"168", " ", 
              SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{
         SubscriptBox["q", "v"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}]}], "+", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"h", "[", 
       RowBox[{"x", ",", "t"}], "]"}], "6"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1632", "+", 
          RowBox[{
           SuperscriptBox["\[Mu]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"8851", "-", 
             RowBox[{"9866", " ", "\[Rho]"}]}], ")"}]}], "-", 
          RowBox[{"1877", " ", "\[Rho]"}], "+", 
          RowBox[{"126", " ", 
           SuperscriptBox["\[Rho]", "2"]}], "+", 
          RowBox[{"12", " ", 
           SuperscriptBox["\[Mu]", "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "338"}], "+", 
             RowBox[{"373", " ", "\[Rho]"}]}], ")"}]}], "+", 
          RowBox[{"\[Mu]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "6213"}], "+", 
             RowBox[{"6927", " ", "\[Rho]"}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{
         SubscriptBox["q", "l"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"14", " ", "\[Rho]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "67"}], "+", 
             RowBox[{"9", " ", "\[Rho]"}]}], ")"}]}], "+", 
          RowBox[{"7", " ", 
           SuperscriptBox["\[Mu]", "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "47"}], "+", 
             RowBox[{"302", " ", "\[Rho]"}]}], ")"}]}], "+", 
          RowBox[{"5", " ", "\[Mu]", " ", 
           RowBox[{"(", 
            RowBox[{"320", "+", 
             RowBox[{"283", " ", "\[Rho]"}], "+", 
             RowBox[{"90", " ", 
              SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}], "-", 
          RowBox[{
           SuperscriptBox["\[Mu]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"877", "+", 
             RowBox[{"3291", " ", "\[Rho]"}], "+", 
             RowBox[{"270", " ", 
              SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{
         SubscriptBox["q", "v"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}]}]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"560", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "\[Rho]"}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"h", "[", 
        RowBox[{"x", ",", "t"}], "]"}]}], ")"}], "2"], " ", 
    SuperscriptBox[
     RowBox[{"h", "[", 
      RowBox[{"x", ",", "t"}], "]"}], "2"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "\[Mu]"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[Mu]"}], ")"}], " ", 
        RowBox[{"h", "[", 
         RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}], "3"]}], ")"}]}]], "Output",\
ExpressionUUID->"fd81c091-8777-40b3-b926-95ff979ee343"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["In 2.24(b), ",
  FontFamily->"Arial",
  FontColor->RGBColor[1, 0, 0]],
 Cell[BoxData[
  FormBox[
   SubscriptBox["M", "1"], TraditionalForm]],
  FontFamily->"Arial",
  FontColor->RGBColor[1, 0, 0],ExpressionUUID->
  "46051bfd-1785-4e21-902c-776e7f19a4ab"],
 StyleBox[" is given by",
  FontFamily->"Arial",
  FontColor->RGBColor[1, 0, 0]]
}], "Subsection",
 CellFrame->{{0, 0}, {
   0, 0.5}},ExpressionUUID->"83ded633-b232-4ecd-b18e-a5d97a616080"],

Cell[BoxData[
 RowBox[{"-", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"3", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"8", " ", 
         SuperscriptBox["\[Mu]", "4"], " ", 
         SuperscriptBox[
          RowBox[{
           SubscriptBox["q", "v"], "[", 
           RowBox[{"x", ",", "t"}], "]"}], "2"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["\[Mu]", "3"], " ", 
         RowBox[{"h", "[", 
          RowBox[{"x", ",", "t"}], "]"}], " ", 
         RowBox[{
          SubscriptBox["q", "v"], "[", 
          RowBox[{"x", ",", "t"}], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "\[Mu]", " ", 
            RowBox[{
             SubscriptBox["q", "l"], "[", 
             RowBox[{"x", ",", "t"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "22"}], "+", 
              RowBox[{"25", " ", "\[Mu]"}]}], ")"}], " ", 
            RowBox[{
             SubscriptBox["q", "v"], "[", 
             RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}]}], "+", 
        RowBox[{
         SuperscriptBox["\[Mu]", "2"], " ", 
         SuperscriptBox[
          RowBox[{"h", "[", 
           RowBox[{"x", ",", "t"}], "]"}], "2"], " ", 
         RowBox[{
          SubscriptBox["q", "v"], "[", 
          RowBox[{"x", ",", "t"}], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "\[Mu]", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "19"}], "+", 
              RowBox[{"28", " ", "\[Mu]"}]}], ")"}], " ", 
            RowBox[{
             SubscriptBox["q", "l"], "[", 
             RowBox[{"x", ",", "t"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"100", "+", 
              RowBox[{"357", " ", 
               SuperscriptBox["\[Mu]", "2"]}], "+", 
              RowBox[{"\[Mu]", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "555"}], "+", 
                 RowBox[{"77", " ", "\[Rho]"}]}], ")"}]}]}], ")"}], " ", 
            RowBox[{
             SubscriptBox["q", "v"], "[", 
             RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}]}], "+", 
        RowBox[{"8", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "\[Mu]"}], ")"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"h", "[", 
           RowBox[{"x", ",", "t"}], "]"}], "10"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"12", "-", 
              RowBox[{"19", " ", "\[Mu]"}], "+", 
              RowBox[{"10", " ", 
               SuperscriptBox["\[Mu]", "2"]}], "-", 
              RowBox[{"3", " ", "\[Rho]"}]}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{
              SubscriptBox["q", "l"], "[", 
              RowBox[{"x", ",", "t"}], "]"}], "2"]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["\[Mu]", "2"], "-", 
              RowBox[{"5", " ", "\[Mu]", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "\[Rho]"}], ")"}]}], "-", 
              "\[Rho]"}], ")"}], " ", 
            RowBox[{
             SubscriptBox["q", "l"], "[", 
             RowBox[{"x", ",", "t"}], "]"}], " ", 
            RowBox[{
             SubscriptBox["q", "v"], "[", 
             RowBox[{"x", ",", "t"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SuperscriptBox["\[Mu]", "2"], " ", 
               RowBox[{"(", 
                RowBox[{"3", "-", 
                 RowBox[{"12", " ", "\[Rho]"}]}], ")"}]}], "-", 
              RowBox[{"10", " ", "\[Rho]"}], "+", 
              RowBox[{"19", " ", "\[Mu]", " ", "\[Rho]"}]}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{
              SubscriptBox["q", "v"], "[", 
              RowBox[{"x", ",", "t"}], "]"}], "2"]}]}], ")"}]}], "+", 
        RowBox[{
         SuperscriptBox["\[Mu]", "2"], " ", 
         SuperscriptBox[
          RowBox[{"h", "[", 
           RowBox[{"x", ",", "t"}], "]"}], "3"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"6", " ", 
            RowBox[{"(", 
             RowBox[{"1", "-", 
              RowBox[{"4", " ", "\[Mu]"}]}], ")"}], " ", "\[Mu]", " ", 
            SuperscriptBox[
             RowBox[{
              SubscriptBox["q", "l"], "[", 
              RowBox[{"x", ",", "t"}], "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{"28", "-", 
              RowBox[{"142", " ", "\[Mu]"}], "+", 
              RowBox[{"123", " ", 
               SuperscriptBox["\[Mu]", "2"]}]}], ")"}], " ", 
            RowBox[{
             SubscriptBox["q", "l"], "[", 
             RowBox[{"x", ",", "t"}], "]"}], " ", 
            RowBox[{
             SubscriptBox["q", "v"], "[", 
             RowBox[{"x", ",", "t"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "724"}], "+", 
              RowBox[{"\[Mu]", " ", 
               RowBox[{"(", 
                RowBox[{"2148", "-", 
                 RowBox[{"616", " ", "\[Rho]"}]}], ")"}]}], "+", 
              RowBox[{"217", " ", "\[Rho]"}], "+", 
              RowBox[{"3", " ", 
               SuperscriptBox["\[Mu]", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "365"}], "+", 
                 RowBox[{"32", " ", "\[Rho]"}]}], ")"}]}]}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{
              SubscriptBox["q", "v"], "[", 
              RowBox[{"x", ",", "t"}], "]"}], "2"]}]}], ")"}]}], "-", 
        RowBox[{"4", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "\[Mu]"}], ")"}], " ", 
         SuperscriptBox[
          RowBox[{"h", "[", 
           RowBox[{"x", ",", "t"}], "]"}], "9"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "72"}], "+", 
              RowBox[{"226", " ", "\[Mu]"}], "-", 
              RowBox[{"277", " ", 
               SuperscriptBox["\[Mu]", "2"]}], "+", 
              RowBox[{"112", " ", 
               SuperscriptBox["\[Mu]", "3"]}], "+", 
              RowBox[{"4", " ", "\[Rho]"}], "+", 
              RowBox[{"7", " ", "\[Mu]", " ", "\[Rho]"}]}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{
              SubscriptBox["q", "l"], "[", 
              RowBox[{"x", ",", "t"}], "]"}], "2"]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"21", " ", 
               SuperscriptBox["\[Mu]", "3"]}], "+", 
              RowBox[{
               SuperscriptBox["\[Mu]", "2"], " ", 
               RowBox[{"(", 
                RowBox[{"22", "-", 
                 RowBox[{"35", " ", "\[Rho]"}]}], ")"}]}], "-", "\[Rho]", "+", 
              RowBox[{"\[Mu]", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "65"}], "+", 
                 RowBox[{"58", " ", "\[Rho]"}]}], ")"}]}]}], ")"}], " ", 
            RowBox[{
             SubscriptBox["q", "l"], "[", 
             RowBox[{"x", ",", "t"}], "]"}], " ", 
            RowBox[{
             SubscriptBox["q", "v"], "[", 
             RowBox[{"x", ",", "t"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"88", " ", "\[Rho]"}], "-", 
              RowBox[{"303", " ", "\[Mu]", " ", "\[Rho]"}], "-", 
              RowBox[{"56", " ", 
               SuperscriptBox["\[Mu]", "3"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 RowBox[{"3", " ", "\[Rho]"}]}], ")"}]}], "+", 
              RowBox[{
               SuperscriptBox["\[Mu]", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "67"}], "+", 
                 RowBox[{"394", " ", "\[Rho]"}]}], ")"}]}]}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{
              SubscriptBox["q", "v"], "[", 
              RowBox[{"x", ",", "t"}], "]"}], "2"]}]}], ")"}]}], "-", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"h", "[", 
           RowBox[{"x", ",", "t"}], "]"}], "7"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"96", "-", 
              RowBox[{"3726", " ", 
               SuperscriptBox["\[Mu]", "3"]}], "+", 
              RowBox[{"1400", " ", 
               SuperscriptBox["\[Mu]", "4"]}], "+", 
              RowBox[{"21", " ", "\[Rho]"}], "-", 
              RowBox[{"24", " ", "\[Mu]", " ", 
               RowBox[{"(", 
                RowBox[{"37", "+", 
                 RowBox[{"7", " ", "\[Rho]"}]}], ")"}]}], "+", 
              RowBox[{
               SuperscriptBox["\[Mu]", "2"], " ", 
               RowBox[{"(", 
                RowBox[{"3195", "+", 
                 RowBox[{"76", " ", "\[Rho]"}]}], ")"}]}]}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{
              SubscriptBox["q", "l"], "[", 
              RowBox[{"x", ",", "t"}], "]"}], "2"]}], "+", 
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"413", " ", 
               SuperscriptBox["\[Mu]", "4"]}], "+", 
              RowBox[{"\[Mu]", " ", 
               RowBox[{"(", 
                RowBox[{"500", "-", 
                 RowBox[{"346", " ", "\[Rho]"}]}], ")"}]}], "+", 
              RowBox[{"21", " ", "\[Rho]"}], "-", 
              RowBox[{"2", " ", 
               SuperscriptBox["\[Mu]", "3"], " ", 
               RowBox[{"(", 
                RowBox[{"357", "+", 
                 RowBox[{"10", " ", "\[Rho]"}]}], ")"}]}], "+", 
              RowBox[{"4", " ", 
               SuperscriptBox["\[Mu]", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "33"}], "+", 
                 RowBox[{"71", " ", "\[Rho]"}]}], ")"}]}]}], ")"}], " ", 
            RowBox[{
             SubscriptBox["q", "l"], "[", 
             RowBox[{"x", ",", "t"}], "]"}], " ", 
            RowBox[{
             SubscriptBox["q", "v"], "[", 
             RowBox[{"x", ",", "t"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SuperscriptBox["\[Mu]", "2"], " ", 
               RowBox[{"(", 
                RowBox[{"2940", "-", 
                 RowBox[{"9837", " ", "\[Rho]"}]}], ")"}]}], "+", 
              RowBox[{
               SuperscriptBox["\[Mu]", "4"], " ", 
               RowBox[{"(", 
                RowBox[{"2157", "-", 
                 RowBox[{"3360", " ", "\[Rho]"}]}], ")"}]}], "-", 
              RowBox[{"584", " ", "\[Rho]"}], "+", 
              RowBox[{"3778", " ", "\[Mu]", " ", "\[Rho]"}], "+", 
              RowBox[{"16", " ", 
               SuperscriptBox["\[Mu]", "3"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "315"}], "+", 
                 RowBox[{"622", " ", "\[Rho]"}]}], ")"}]}]}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{
              SubscriptBox["q", "v"], "[", 
              RowBox[{"x", ",", "t"}], "]"}], "2"]}]}], ")"}]}], "+", 
        RowBox[{"\[Mu]", " ", 
         SuperscriptBox[
          RowBox[{"h", "[", 
           RowBox[{"x", ",", "t"}], "]"}], "4"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"6", " ", "\[Mu]", " ", 
            RowBox[{"(", 
             RowBox[{"3", "-", 
              RowBox[{"30", " ", "\[Mu]"}], "+", 
              RowBox[{"28", " ", 
               SuperscriptBox["\[Mu]", "2"]}]}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{
              SubscriptBox["q", "l"], "[", 
              RowBox[{"x", ",", "t"}], "]"}], "2"]}], "+", 
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{"30", "-", 
              RowBox[{"483", " ", 
               SuperscriptBox["\[Mu]", "2"]}], "+", 
              RowBox[{"322", " ", 
               SuperscriptBox["\[Mu]", "3"]}], "+", 
              RowBox[{"\[Mu]", " ", 
               RowBox[{"(", 
                RowBox[{"153", "-", 
                 RowBox[{"7", " ", "\[Rho]"}]}], ")"}]}]}], ")"}], " ", 
            RowBox[{
             SubscriptBox["q", "l"], "[", 
             RowBox[{"x", ",", "t"}], "]"}], " ", 
            RowBox[{
             SubscriptBox["q", "v"], "[", 
             RowBox[{"x", ",", "t"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SuperscriptBox["\[Mu]", "3"], " ", 
               RowBox[{"(", 
                RowBox[{"2289", "-", 
                 RowBox[{"672", " ", "\[Rho]"}]}], ")"}]}], "+", 
              RowBox[{"154", " ", "\[Rho]"}], "-", 
              RowBox[{"21", " ", "\[Mu]", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "108"}], "+", 
                 RowBox[{"71", " ", "\[Rho]"}]}], ")"}]}], "+", 
              RowBox[{
               SuperscriptBox["\[Mu]", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "4977"}], "+", 
                 RowBox[{"2453", " ", "\[Rho]"}]}], ")"}]}]}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{
              SubscriptBox["q", "v"], "[", 
              RowBox[{"x", ",", "t"}], "]"}], "2"]}]}], ")"}]}], "-", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"h", "[", 
           RowBox[{"x", ",", "t"}], "]"}], "5"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[Mu]", " ", 
            RowBox[{"(", 
             RowBox[{"30", "+", 
              RowBox[{"381", " ", "\[Mu]"}], "-", 
              RowBox[{"968", " ", 
               SuperscriptBox["\[Mu]", "2"]}], "+", 
              RowBox[{"560", " ", 
               SuperscriptBox["\[Mu]", "3"]}]}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{
              SubscriptBox["q", "l"], "[", 
              RowBox[{"x", ",", "t"}], "]"}], "2"]}], "+", 
           RowBox[{"2", " ", "\[Mu]", " ", 
            RowBox[{"(", 
             RowBox[{"170", "+", 
              RowBox[{"539", " ", 
               SuperscriptBox["\[Mu]", "3"]}], "+", 
              RowBox[{"\[Mu]", " ", 
               RowBox[{"(", 
                RowBox[{"302", "-", 
                 RowBox[{"14", " ", "\[Rho]"}]}], ")"}]}], "-", 
              RowBox[{"42", " ", "\[Rho]"}], "+", 
              RowBox[{"2", " ", 
               SuperscriptBox["\[Mu]", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "469"}], "+", 
                 RowBox[{"5", " ", "\[Rho]"}]}], ")"}]}]}], ")"}], " ", 
            RowBox[{
             SubscriptBox["q", "l"], "[", 
             RowBox[{"x", ",", "t"}], "]"}], " ", 
            RowBox[{
             SubscriptBox["q", "v"], "[", 
             RowBox[{"x", ",", "t"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SuperscriptBox["\[Mu]", "2"], " ", 
               RowBox[{"(", 
                RowBox[{"4004", "-", 
                 RowBox[{"4662", " ", "\[Rho]"}]}], ")"}]}], "-", 
              RowBox[{"56", " ", "\[Rho]"}], "+", 
              RowBox[{"938", " ", "\[Mu]", " ", "\[Rho]"}], "-", 
              RowBox[{"21", " ", 
               SuperscriptBox["\[Mu]", "4"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "157"}], "+", 
                 RowBox[{"96", " ", "\[Rho]"}]}], ")"}]}], "+", 
              RowBox[{
               SuperscriptBox["\[Mu]", "3"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "7518"}], "+", 
                 RowBox[{"6064", " ", "\[Rho]"}]}], ")"}]}]}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{
              SubscriptBox["q", "v"], "[", 
              RowBox[{"x", ",", "t"}], "]"}], "2"]}]}], ")"}]}], "+", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"h", "[", 
           RowBox[{"x", ",", "t"}], "]"}], "8"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "3260"}], " ", 
               SuperscriptBox["\[Mu]", "3"]}], "+", 
              RowBox[{"1064", " ", 
               SuperscriptBox["\[Mu]", "4"]}], "+", 
              RowBox[{"3", " ", 
               RowBox[{"(", 
                RowBox[{"96", "+", 
                 RowBox[{"7", " ", "\[Rho]"}]}], ")"}]}], "+", 
              RowBox[{
               SuperscriptBox["\[Mu]", "2"], " ", 
               RowBox[{"(", 
                RowBox[{"3483", "+", 
                 RowBox[{"128", " ", "\[Rho]"}]}], ")"}]}], "-", 
              RowBox[{"\[Mu]", " ", 
               RowBox[{"(", 
                RowBox[{"1559", "+", 
                 RowBox[{"165", " ", "\[Rho]"}]}], ")"}]}]}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{
              SubscriptBox["q", "l"], "[", 
              RowBox[{"x", ",", "t"}], "]"}], "2"]}], "+", 
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"178", " ", 
               SuperscriptBox["\[Mu]", "4"]}], "+", 
              RowBox[{"20", " ", "\[Rho]"}], "-", 
              RowBox[{"5", " ", "\[Mu]", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "70"}], "+", 
                 RowBox[{"61", " ", "\[Rho]"}]}], ")"}]}], "-", 
              RowBox[{
               SuperscriptBox["\[Mu]", "3"], " ", 
               RowBox[{"(", 
                RowBox[{"217", "+", 
                 RowBox[{"80", " ", "\[Rho]"}]}], ")"}]}], "+", 
              RowBox[{
               SuperscriptBox["\[Mu]", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "295"}], "+", 
                 RowBox[{"349", " ", "\[Rho]"}]}], ")"}]}]}], ")"}], " ", 
            RowBox[{
             SubscriptBox["q", "l"], "[", 
             RowBox[{"x", ",", "t"}], "]"}], " ", 
            RowBox[{
             SubscriptBox["q", "v"], "[", 
             RowBox[{"x", ",", "t"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SuperscriptBox["\[Mu]", "2"], " ", 
               RowBox[{"(", 
                RowBox[{"1204", "-", 
                 RowBox[{"6975", " ", "\[Rho]"}]}], ")"}]}], "+", 
              RowBox[{
               SuperscriptBox["\[Mu]", "4"], " ", 
               RowBox[{"(", 
                RowBox[{"915", "-", 
                 RowBox[{"2016", " ", "\[Rho]"}]}], ")"}]}], "-", 
              RowBox[{"632", " ", "\[Rho]"}], "+", 
              RowBox[{"3296", " ", "\[Mu]", " ", "\[Rho]"}], "+", 
              RowBox[{
               SuperscriptBox["\[Mu]", "3"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "2103"}], "+", 
                 RowBox[{"6311", " ", "\[Rho]"}]}], ")"}]}]}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{
              SubscriptBox["q", "v"], "[", 
              RowBox[{"x", ",", "t"}], "]"}], "2"]}]}], ")"}]}], "+", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"h", "[", 
           RowBox[{"x", ",", "t"}], "]"}], "6"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[Mu]", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"1607", " ", "\[Mu]"}], "-", 
              RowBox[{"2504", " ", 
               SuperscriptBox["\[Mu]", "2"]}], "+", 
              RowBox[{"1120", " ", 
               SuperscriptBox["\[Mu]", "3"]}], "-", 
              RowBox[{"21", " ", 
               RowBox[{"(", 
                RowBox[{"7", "+", 
                 RowBox[{"3", " ", "\[Rho]"}]}], ")"}]}]}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{
              SubscriptBox["q", "l"], "[", 
              RowBox[{"x", ",", "t"}], "]"}], "2"]}], "+", 
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"588", " ", 
               SuperscriptBox["\[Mu]", "4"]}], "+", 
              RowBox[{"\[Mu]", " ", 
               RowBox[{"(", 
                RowBox[{"400", "-", 
                 RowBox[{"189", " ", "\[Rho]"}]}], ")"}]}], "+", 
              RowBox[{"7", " ", "\[Rho]"}], "+", 
              RowBox[{"5", " ", 
               SuperscriptBox["\[Mu]", "3"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "217"}], "+", 
                 RowBox[{"4", " ", "\[Rho]"}]}], ")"}]}], "+", 
              RowBox[{
               SuperscriptBox["\[Mu]", "2"], " ", 
               RowBox[{"(", 
                RowBox[{"202", "+", 
                 RowBox[{"78", " ", "\[Rho]"}]}], ")"}]}]}], ")"}], " ", 
            RowBox[{
             SubscriptBox["q", "l"], "[", 
             RowBox[{"x", ",", "t"}], "]"}], " ", 
            RowBox[{
             SubscriptBox["q", "v"], "[", 
             RowBox[{"x", ",", "t"}], "]"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SuperscriptBox["\[Mu]", "2"], " ", 
               RowBox[{"(", 
                RowBox[{"4340", "-", 
                 RowBox[{"8558", " ", "\[Rho]"}]}], ")"}]}], "-", 
              RowBox[{"280", " ", "\[Rho]"}], "+", 
              RowBox[{"2518", " ", "\[Mu]", " ", "\[Rho]"}], "-", 
              RowBox[{"105", " ", 
               SuperscriptBox["\[Mu]", "4"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "31"}], "+", 
                 RowBox[{"32", " ", "\[Rho]"}]}], ")"}]}], "+", 
              RowBox[{
               SuperscriptBox["\[Mu]", "3"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "7581"}], "+", 
                 RowBox[{"9695", " ", "\[Rho]"}]}], ")"}]}]}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{
              SubscriptBox["q", "v"], "[", 
              RowBox[{"x", ",", "t"}], "]"}], "2"]}]}], ")"}]}]}], ")"}]}], 
     ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"560", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"h", "[", 
          RowBox[{"x", ",", "t"}], "]"}]}], ")"}], "3"], " ", 
      SuperscriptBox[
       RowBox[{"h", "[", 
        RowBox[{"x", ",", "t"}], "]"}], "3"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"\[Mu]", "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "\[Mu]"}], ")"}], " ", 
          RowBox[{"h", "[", 
           RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}], "4"]}], ")"}]}], 
   ")"}]}]], "Output",ExpressionUUID->"d9545587-8182-4b88-aadd-a795cadaf8e4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["In 2.24(b), ",
  FontFamily->"Arial",
  FontColor->RGBColor[1, 0, 0]],
 Cell[BoxData[
  FormBox[
   SubscriptBox["V", "1"], TraditionalForm]], "Subsection",
  FontFamily->"Arial",
  FontColor->RGBColor[1, 0, 0],ExpressionUUID->
  "89aa04a8-7fda-437b-ab9e-a3507b86bbde"],
 StyleBox[" is given by",
  FontFamily->"Arial",
  FontColor->RGBColor[1, 0, 0]]
}], "Subsection",
 CellFrame->{{0, 0}, {
   0, 0.5}},ExpressionUUID->"067faa09-973f-4d30-9525-42608b017e60"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["\[Mu]", "2"], "-", 
    RowBox[{"\[Mu]", " ", 
     RowBox[{"(", 
      RowBox[{"4", "+", 
       RowBox[{"5", " ", "\[Mu]"}]}], ")"}], " ", 
     RowBox[{"h", "[", 
      RowBox[{"x", ",", "t"}], "]"}]}], "+", 
    RowBox[{"\[Mu]", " ", 
     RowBox[{"(", 
      RowBox[{"16", "+", 
       RowBox[{"5", " ", "\[Mu]"}], "-", 
       RowBox[{"25", " ", "\[Rho]"}]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"h", "[", 
       RowBox[{"x", ",", "t"}], "]"}], "2"]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[Mu]", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"5", "-", 
          RowBox[{"32", " ", "\[Rho]"}]}], ")"}]}], "-", 
       RowBox[{"20", " ", "\[Rho]"}], "+", 
       RowBox[{"3", " ", "\[Mu]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "8"}], "+", 
          RowBox[{"25", " ", "\[Rho]"}]}], ")"}]}]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"h", "[", 
       RowBox[{"x", ",", "t"}], "]"}], "3"]}], "+", 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Mu]", " ", 
        RowBox[{"(", 
         RowBox[{"8", "-", 
          RowBox[{"55", " ", "\[Rho]"}]}], ")"}]}], "+", 
       RowBox[{"20", " ", "\[Rho]"}], "+", 
       RowBox[{
        SuperscriptBox["\[Mu]", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          RowBox[{"32", " ", "\[Rho]"}]}], ")"}]}]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"h", "[", 
       RowBox[{"x", ",", "t"}], "]"}], "4"]}], "-", 
    RowBox[{"4", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "\[Mu]"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "7"}], " ", "\[Rho]"}], "+", 
       RowBox[{"\[Mu]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"8", " ", "\[Rho]"}]}], ")"}]}]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"h", "[", 
       RowBox[{"x", ",", "t"}], "]"}], "5"]}]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"80", " ", 
    RowBox[{"h", "[", 
     RowBox[{"x", ",", "t"}], "]"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"\[Mu]", "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[Mu]"}], ")"}], " ", 
        RowBox[{"h", "[", 
         RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}], "2"]}], ")"}]}]], "Output",\
ExpressionUUID->"2a750f5a-8baa-4f22-b38d-a4c4a4d8c9a1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["In 2.24(b), ",
  FontFamily->"Arial",
  FontColor->RGBColor[1, 0, 0]],
 Cell[BoxData[
  FormBox[
   SubscriptBox["V", "2"], TraditionalForm]],
  FontFamily->"Arial",
  FontColor->RGBColor[1, 0, 0],ExpressionUUID->
  "5ceb137c-64cc-42ae-8c73-165073ac778c"],
 StyleBox[" is given by",
  FontFamily->"Arial",
  FontColor->RGBColor[1, 0, 0]]
}], "Subsection",
 CellFrame->{{0, 0}, {
   0, 0.5}},ExpressionUUID->"4f160a1f-f540-4570-83f8-5bbd47ea56b4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Mu]", "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "24"}], "+", 
       RowBox[{"17", " ", "\[Rho]"}]}], ")"}], " ", 
     RowBox[{
      SubscriptBox["q", "v"], "[", 
      RowBox[{"x", ",", "t"}], "]"}]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["\[Mu]", "2"], " ", 
     RowBox[{"h", "[", 
      RowBox[{"x", ",", "t"}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"9", " ", "\[Mu]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[Rho]"}], ")"}], " ", 
        RowBox[{
         SubscriptBox["q", "l"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"75", "+", 
          RowBox[{"96", " ", "\[Mu]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "\[Rho]"}], ")"}]}], "-", 
          RowBox[{"82", " ", "\[Rho]"}]}], ")"}], " ", 
        RowBox[{
         SubscriptBox["q", "v"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}]}], "+", 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "\[Mu]"}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"h", "[", 
       RowBox[{"x", ",", "t"}], "]"}], "8"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"65", "-", 
             RowBox[{"9", " ", "\[Rho]"}]}], ")"}], " ", "\[Rho]"}], "+", 
          RowBox[{
           SuperscriptBox["\[Mu]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "30"}], "+", 
             RowBox[{"86", " ", "\[Rho]"}]}], ")"}]}], "-", 
          RowBox[{"\[Mu]", " ", 
           RowBox[{"(", 
            RowBox[{"45", "+", "\[Rho]", "+", 
             RowBox[{"66", " ", 
              SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{
         SubscriptBox["q", "l"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"4", " ", 
           RowBox[{"(", 
            RowBox[{"73", "-", 
             RowBox[{"59", " ", "\[Rho]"}]}], ")"}], " ", "\[Rho]"}], "+", 
          RowBox[{"\[Mu]", " ", "\[Rho]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "545"}], "+", 
             RowBox[{"433", " ", "\[Rho]"}]}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["\[Mu]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "75"}], "+", 
             RowBox[{"403", " ", "\[Rho]"}], "-", 
             RowBox[{"272", " ", 
              SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{
         SubscriptBox["q", "v"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}]}], "+", 
    RowBox[{"\[Mu]", " ", 
     SuperscriptBox[
      RowBox[{"h", "[", 
       RowBox[{"x", ",", "t"}], "]"}], "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Mu]", " ", 
        RowBox[{"(", 
         RowBox[{"54", "-", 
          RowBox[{"47", " ", "\[Rho]"}], "+", 
          RowBox[{"14", " ", "\[Mu]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "9"}], "+", 
             RowBox[{"7", " ", "\[Rho]"}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{
         SubscriptBox["q", "l"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}], "+", 
       RowBox[{"7", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"8", " ", "\[Rho]"}], "+", 
          RowBox[{"3", " ", 
           SuperscriptBox["\[Mu]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "38"}], "+", 
             RowBox[{"49", " ", "\[Rho]"}]}], ")"}]}], "+", 
          RowBox[{"\[Mu]", " ", 
           RowBox[{"(", 
            RowBox[{"150", "-", 
             RowBox[{"257", " ", "\[Rho]"}], "+", 
             RowBox[{"61", " ", 
              SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{
         SubscriptBox["q", "v"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}]}], "+", 
    RowBox[{"2", " ", "\[Mu]", " ", 
     SuperscriptBox[
      RowBox[{"h", "[", 
       RowBox[{"x", ",", "t"}], "]"}], "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "45"}], "+", 
          RowBox[{"31", " ", "\[Rho]"}], "-", 
          RowBox[{"42", " ", 
           SuperscriptBox["\[Mu]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "5"}], "+", 
             RowBox[{"3", " ", "\[Rho]"}]}], ")"}]}], "+", 
          RowBox[{"2", " ", "\[Mu]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "81"}], "+", 
             RowBox[{"74", " ", "\[Rho]"}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{
         SubscriptBox["q", "l"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"7", " ", "\[Rho]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "89"}], "+", 
             RowBox[{"48", " ", "\[Rho]"}]}], ")"}]}], "-", 
          RowBox[{"7", " ", "\[Mu]", " ", 
           RowBox[{"(", 
            RowBox[{"225", "-", 
             RowBox[{"530", " ", "\[Rho]"}], "+", 
             RowBox[{"183", " ", 
              SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["\[Mu]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"1050", "-", 
             RowBox[{"1833", " ", "\[Rho]"}], "+", 
             RowBox[{"272", " ", 
              SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{
         SubscriptBox["q", "v"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}]}], "+", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"h", "[", 
       RowBox[{"x", ",", "t"}], "]"}], "4"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Mu]", " ", 
        RowBox[{"(", 
         RowBox[{"450", "-", 
          RowBox[{"726", " ", "\[Mu]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "\[Rho]"}], ")"}]}], "-", 
          RowBox[{"373", " ", "\[Rho]"}], "+", 
          RowBox[{"63", " ", 
           SuperscriptBox["\[Rho]", "2"]}], "+", 
          RowBox[{"280", " ", 
           SuperscriptBox["\[Mu]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "3"}], "+", 
             RowBox[{"2", " ", "\[Rho]"}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{
         SubscriptBox["q", "l"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"28", " ", "\[Rho]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "17"}], "+", 
             RowBox[{"12", " ", "\[Rho]"}]}], ")"}]}], "-", 
          RowBox[{"35", " ", "\[Mu]", " ", "\[Rho]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "154"}], "+", 
             RowBox[{"95", " ", "\[Rho]"}]}], ")"}]}], "-", 
          RowBox[{"5", " ", 
           SuperscriptBox["\[Mu]", "3"], " ", 
           RowBox[{"(", 
            RowBox[{"714", "-", 
             RowBox[{"1685", " ", "\[Rho]"}], "+", 
             RowBox[{"544", " ", 
              SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}], "+", 
          RowBox[{"6", " ", 
           SuperscriptBox["\[Mu]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"875", "-", 
             RowBox[{"2811", " ", "\[Rho]"}], "+", 
             RowBox[{"1236", " ", 
              SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{
         SubscriptBox["q", "v"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox[
      RowBox[{"h", "[", 
       RowBox[{"x", ",", "t"}], "]"}], "7"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"121", "-", 
             RowBox[{"16", " ", "\[Rho]"}]}], ")"}], " ", "\[Rho]"}], "-", 
          RowBox[{"28", " ", 
           SuperscriptBox["\[Mu]", "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "6"}], "+", 
             RowBox[{"13", " ", "\[Rho]"}]}], ")"}]}], "+", 
          RowBox[{"\[Mu]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "225"}], "+", 
             RowBox[{"24", " ", "\[Rho]"}], "-", 
             RowBox[{"205", " ", 
              SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["\[Mu]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"6", "+", 
             RowBox[{"321", " ", "\[Rho]"}], "+", 
             RowBox[{"170", " ", 
              SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{
         SubscriptBox["q", "l"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"4", " ", 
           RowBox[{"(", 
            RowBox[{"265", "-", 
             RowBox[{"202", " ", "\[Rho]"}]}], ")"}], " ", "\[Rho]"}], "+", 
          RowBox[{"\[Mu]", " ", "\[Rho]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "3505"}], "+", 
             RowBox[{"2658", " ", "\[Rho]"}]}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["\[Mu]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "525"}], "+", 
             RowBox[{"4724", " ", "\[Rho]"}], "-", 
             RowBox[{"3261", " ", 
              SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["\[Mu]", "3"], " ", 
           RowBox[{"(", 
            RowBox[{"474", "-", 
             RowBox[{"2177", " ", "\[Rho]"}], "+", 
             RowBox[{"1360", " ", 
              SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{
         SubscriptBox["q", "v"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox[
      RowBox[{"h", "[", 
       RowBox[{"x", ",", "t"}], "]"}], "5"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"525", " ", 
           SuperscriptBox["\[Mu]", "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "\[Rho]"}], ")"}]}], "+", 
          RowBox[{"14", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "+", "\[Rho]"}], ")"}], " ", "\[Rho]"}], "+", 
          RowBox[{
           SuperscriptBox["\[Mu]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"372", "-", 
             RowBox[{"523", " ", "\[Rho]"}], "-", 
             RowBox[{"38", " ", 
              SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}], "+", 
          RowBox[{"\[Mu]", " ", 
           RowBox[{"(", 
            RowBox[{"450", "-", 
             RowBox[{"436", " ", "\[Rho]"}], "+", 
             RowBox[{"161", " ", 
              SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{
         SubscriptBox["q", "l"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Mu]", " ", 
           RowBox[{"(", 
            RowBox[{"5464", "-", 
             RowBox[{"3637", " ", "\[Rho]"}]}], ")"}], " ", "\[Rho]"}], "+", 
          RowBox[{"56", " ", "\[Rho]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "17"}], "+", 
             RowBox[{"12", " ", "\[Rho]"}]}], ")"}]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["\[Mu]", "3"], " ", 
           RowBox[{"(", 
            RowBox[{"966", "-", 
             RowBox[{"2963", " ", "\[Rho]"}], "+", 
             RowBox[{"1360", " ", 
              SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["\[Mu]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"2625", "-", 
             RowBox[{"11752", " ", "\[Rho]"}], "+", 
             RowBox[{"6278", " ", 
              SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{
         SubscriptBox["q", "v"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}]}], "+", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"h", "[", 
       RowBox[{"x", ",", "t"}], "]"}], "6"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"7", " ", "\[Rho]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "24"}], "+", 
             RowBox[{"7", " ", "\[Rho]"}]}], ")"}]}], "+", 
          RowBox[{"42", " ", 
           SuperscriptBox["\[Mu]", "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "19"}], "+", 
             RowBox[{"29", " ", "\[Rho]"}]}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["\[Mu]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"306", "-", 
             RowBox[{"1037", " ", "\[Rho]"}], "-", 
             RowBox[{"284", " ", 
              SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}], "+", 
          RowBox[{"\[Mu]", " ", 
           RowBox[{"(", 
            RowBox[{"900", "-", 
             RowBox[{"741", " ", "\[Rho]"}], "+", 
             RowBox[{"555", " ", 
              SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{
         SubscriptBox["q", "l"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Mu]", " ", 
           RowBox[{"(", 
            RowBox[{"12064", "-", 
             RowBox[{"8599", " ", "\[Rho]"}]}], ")"}], " ", "\[Rho]"}], "+", 
          RowBox[{"4", " ", "\[Rho]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "741"}], "+", 
             RowBox[{"538", " ", "\[Rho]"}]}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["\[Mu]", "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2562"}], "+", 
             RowBox[{"9787", " ", "\[Rho]"}], "-", 
             RowBox[{"5440", " ", 
              SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["\[Mu]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"3150", "-", 
             RowBox[{"19975", " ", "\[Rho]"}], "+", 
             RowBox[{"12387", " ", 
              SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{
         SubscriptBox["q", "v"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}]}]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"560", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "\[Rho]"}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"h", "[", 
        RowBox[{"x", ",", "t"}], "]"}]}], ")"}], "2"], " ", 
    SuperscriptBox[
     RowBox[{"h", "[", 
      RowBox[{"x", ",", "t"}], "]"}], "2"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "\[Mu]"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[Mu]"}], ")"}], " ", 
        RowBox[{"h", "[", 
         RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}], "3"]}], ")"}]}]], "Output",\
ExpressionUUID->"9fcb7bfa-1cd2-48be-b9cf-1955550c07b8"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["In 2.24(c), ",
  FontFamily->"Arial",
  FontColor->RGBColor[1, 0, 0]],
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    OverscriptBox["L", "-"], "1"], TraditionalForm]],
  FontFamily->"Arial",
  FontColor->RGBColor[1, 0, 0],ExpressionUUID->
  "63ca6215-9aa4-4963-a4fc-34b98d110dce"],
 StyleBox[" is given by",
  FontFamily->"Arial",
  FontColor->RGBColor[1, 0, 0]]
}], "Subsection",
 CellFrame->{{0, 0}, {
   0, 0.5}},ExpressionUUID->"4baae16c-8b01-428e-872e-2eaf6a7a9fc3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "8"}], " ", 
     SuperscriptBox["\[Mu]", "2"]}], "+", 
    RowBox[{"5", " ", "\[Mu]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "7"}], "+", 
       RowBox[{"8", " ", "\[Mu]"}]}], ")"}], " ", 
     RowBox[{"h", "[", 
      RowBox[{"x", ",", "t"}], "]"}]}], "-", 
    RowBox[{"4", " ", 
     RowBox[{"(", 
      RowBox[{"8", "-", 
       RowBox[{"35", " ", "\[Mu]"}], "+", 
       RowBox[{"15", " ", 
        SuperscriptBox["\[Mu]", "2"]}]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"h", "[", 
       RowBox[{"x", ",", "t"}], "]"}], "2"]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"96", "-", 
       RowBox[{"185", " ", "\[Mu]"}], "+", 
       RowBox[{"20", " ", 
        SuperscriptBox["\[Mu]", "2"]}], "-", 
       RowBox[{"5", " ", "\[Rho]"}]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"h", "[", 
       RowBox[{"x", ",", "t"}], "]"}], "3"]}], "+", 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "48"}], "+", 
       RowBox[{"10", " ", 
        SuperscriptBox["\[Mu]", "2"]}], "+", 
       RowBox[{"5", " ", "\[Rho]"}], "+", 
       RowBox[{"\[Mu]", " ", 
        RowBox[{"(", 
         RowBox[{"45", "+", 
          RowBox[{"2", " ", "\[Rho]"}]}], ")"}]}]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"h", "[", 
       RowBox[{"x", ",", "t"}], "]"}], "4"]}], "-", 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "16"}], "+", 
       RowBox[{"6", " ", 
        SuperscriptBox["\[Mu]", "2"]}], "+", 
       RowBox[{"3", " ", "\[Rho]"}], "+", 
       RowBox[{"\[Mu]", " ", 
        RowBox[{"(", 
         RowBox[{"5", "+", 
          RowBox[{"2", " ", "\[Rho]"}]}], ")"}]}]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"h", "[", 
       RowBox[{"x", ",", "t"}], "]"}], "5"]}]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"80", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"h", "[", 
       RowBox[{"x", ",", "t"}], "]"}]}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"\[Mu]", "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[Mu]"}], ")"}], " ", 
        RowBox[{"h", "[", 
         RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}], "2"]}], ")"}]}]], "Output",\
ExpressionUUID->"89178cba-7b54-43da-874e-4d22829ae62a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["In 2.24(c), ",
  FontFamily->"Arial",
  FontColor->RGBColor[1, 0, 0]],
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    OverscriptBox["L", "-"], "2"], TraditionalForm]],
  FontFamily->"Arial",
  FontColor->RGBColor[1, 0, 0],ExpressionUUID->
  "2b58226c-2597-432e-b1a9-0185323e379e"],
 StyleBox[" is given by",
  FontFamily->"Arial",
  FontColor->RGBColor[1, 0, 0]]
}], "Subsection",
 CellFrame->{{0, 0}, {
   0, 0.5}},ExpressionUUID->"c04b2262-7f24-4aa0-bbe4-31f77b62eec8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"7", " ", 
     SuperscriptBox["\[Mu]", "3"], " ", 
     RowBox[{
      SubscriptBox["q", "v"], "[", 
      RowBox[{"x", ",", "t"}], "]"}]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["\[Mu]", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "7"}], "+", 
       RowBox[{"37", " ", "\[Mu]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[Rho]"}], ")"}]}]}], ")"}], " ", 
     RowBox[{"h", "[", 
      RowBox[{"x", ",", "t"}], "]"}], " ", 
     RowBox[{
      SubscriptBox["q", "v"], "[", 
      RowBox[{"x", ",", "t"}], "]"}]}], "+", 
    RowBox[{"\[Mu]", " ", 
     SuperscriptBox[
      RowBox[{"h", "[", 
       RowBox[{"x", ",", "t"}], "]"}], "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Mu]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "7"}], "-", 
          RowBox[{"4", " ", "\[Mu]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "34"}], "+", 
             RowBox[{"27", " ", "\[Rho]"}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{
         SubscriptBox["q", "l"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "56"}], "-", 
          RowBox[{"7", " ", 
           SuperscriptBox["\[Mu]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "51"}], "+", 
             RowBox[{"74", " ", "\[Rho]"}]}], ")"}]}], "+", 
          RowBox[{"\[Mu]", " ", 
           RowBox[{"(", 
            RowBox[{"65", "+", 
             RowBox[{"257", " ", "\[Rho]"}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{
         SubscriptBox["q", "v"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}]}], "+", 
    RowBox[{"2", " ", "\[Mu]", " ", 
     SuperscriptBox[
      RowBox[{"h", "[", 
       RowBox[{"x", ",", "t"}], "]"}], "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{"7", "+", 
          RowBox[{"\[Mu]", " ", 
           RowBox[{"(", 
            RowBox[{"184", "-", 
             RowBox[{"177", " ", "\[Rho]"}]}], ")"}]}], "+", 
          RowBox[{"6", " ", 
           SuperscriptBox["\[Mu]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "34"}], "+", 
             RowBox[{"27", " ", "\[Rho]"}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{
         SubscriptBox["q", "l"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"206", "+", 
          RowBox[{"81", " ", "\[Rho]"}], "+", 
          RowBox[{"7", " ", 
           SuperscriptBox["\[Mu]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "68"}], "+", 
             RowBox[{"107", " ", "\[Rho]"}]}], ")"}]}], "-", 
          RowBox[{"\[Mu]", " ", 
           RowBox[{"(", 
            RowBox[{"13", "+", 
             RowBox[{"771", " ", "\[Rho]"}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{
         SubscriptBox["q", "v"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox[
      RowBox[{"h", "[", 
       RowBox[{"x", ",", "t"}], "]"}], "8"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "272"}], "+", 
          RowBox[{"330", " ", "\[Rho]"}], "-", 
          RowBox[{"51", " ", 
           SuperscriptBox["\[Rho]", "2"]}], "+", 
          RowBox[{"4", " ", 
           SuperscriptBox["\[Mu]", "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "25"}], "+", 
             RowBox[{"46", " ", "\[Rho]"}]}], ")"}]}], "-", 
          RowBox[{
           SuperscriptBox["\[Mu]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"32", "+", 
             RowBox[{"129", " ", "\[Rho]"}]}], ")"}]}], "+", 
          RowBox[{"\[Mu]", " ", 
           RowBox[{"(", 
            RowBox[{"278", "-", 
             RowBox[{"133", " ", "\[Rho]"}], "-", 
             RowBox[{"75", " ", 
              SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{
         SubscriptBox["q", "l"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"12", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "8"}], "+", "\[Rho]"}], ")"}], " ", "\[Rho]"}], "+", 
          RowBox[{
           SuperscriptBox["\[Mu]", "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "16"}], "+", 
             RowBox[{"9", " ", "\[Rho]"}]}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["\[Mu]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"76", "-", 
             RowBox[{"191", " ", "\[Rho]"}], "+", 
             RowBox[{"45", " ", 
              SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}], "+", 
          RowBox[{"\[Mu]", " ", 
           RowBox[{"(", 
            RowBox[{"66", "+", 
             RowBox[{"26", " ", "\[Rho]"}], "+", 
             RowBox[{"69", " ", 
              SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{
         SubscriptBox["q", "v"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}]}], "-", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"h", "[", 
       RowBox[{"x", ",", "t"}], "]"}], "4"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Mu]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "871"}], "+", 
          RowBox[{"\[Mu]", " ", 
           RowBox[{"(", 
            RowBox[{"3610", "-", 
             RowBox[{"3540", " ", "\[Rho]"}]}], ")"}]}], "+", 
          RowBox[{"1011", " ", "\[Rho]"}], "+", 
          RowBox[{"8", " ", 
           SuperscriptBox["\[Mu]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "213"}], "+", 
             RowBox[{"143", " ", "\[Rho]"}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{
         SubscriptBox["q", "l"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox["\[Mu]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"418", "-", 
             RowBox[{"3918", " ", "\[Rho]"}]}], ")"}]}], "-", 
          RowBox[{"140", " ", "\[Rho]"}], "+", 
          RowBox[{"35", " ", 
           SuperscriptBox["\[Mu]", "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "43"}], "+", 
             RowBox[{"66", " ", "\[Rho]"}]}], ")"}]}], "+", 
          RowBox[{"\[Mu]", " ", 
           RowBox[{"(", 
            RowBox[{"1220", "+", 
             RowBox[{"761", " ", "\[Rho]"}], "+", 
             RowBox[{"84", " ", 
              SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{
         SubscriptBox["q", "v"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox[
      RowBox[{"h", "[", 
       RowBox[{"x", ",", "t"}], "]"}], "5"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"272", "+", 
          RowBox[{
           SuperscriptBox["\[Mu]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"3274", "-", 
             RowBox[{"3085", " ", "\[Rho]"}]}], ")"}]}], "-", 
          RowBox[{"286", " ", "\[Rho]"}], "+", 
          RowBox[{"16", " ", 
           SuperscriptBox["\[Mu]", "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "43"}], "+", 
             RowBox[{"8", " ", "\[Rho]"}]}], ")"}]}], "+", 
          RowBox[{"\[Mu]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1882"}], "+", 
             RowBox[{"2057", " ", "\[Rho]"}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{
         SubscriptBox["q", "l"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"7", " ", "\[Rho]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "43"}], "+", 
             RowBox[{"3", " ", "\[Rho]"}]}], ")"}]}], "+", 
          RowBox[{"7", " ", 
           SuperscriptBox["\[Mu]", "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "103"}], "+", 
             RowBox[{"145", " ", "\[Rho]"}]}], ")"}]}], "+", 
          RowBox[{"3", " ", 
           SuperscriptBox["\[Mu]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"187", "-", 
             RowBox[{"909", " ", "\[Rho]"}], "+", 
             RowBox[{"15", " ", 
              SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}], "+", 
          RowBox[{"\[Mu]", " ", 
           RowBox[{"(", 
            RowBox[{"940", "+", 
             RowBox[{"705", " ", "\[Rho]"}], "+", 
             RowBox[{"168", " ", 
              SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{
         SubscriptBox["q", "v"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox[
      RowBox[{"h", "[", 
       RowBox[{"x", ",", "t"}], "]"}], "7"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"816", "+", 
          RowBox[{
           SuperscriptBox["\[Mu]", "3"], " ", 
           RowBox[{"(", 
            RowBox[{"264", "-", 
             RowBox[{"628", " ", "\[Rho]"}]}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["\[Mu]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"818", "-", 
             RowBox[{"349", " ", "\[Rho]"}]}], ")"}]}], "-", 
          RowBox[{"991", " ", "\[Rho]"}], "+", 
          RowBox[{"126", " ", 
           SuperscriptBox["\[Rho]", "2"]}], "+", 
          RowBox[{"\[Mu]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1525"}], "+", 
             RowBox[{"1394", " ", "\[Rho]"}], "+", 
             RowBox[{"75", " ", 
              SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{
         SubscriptBox["q", "l"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"7", " ", 
           SuperscriptBox["\[Mu]", "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "18"}], "+", 
             RowBox[{"17", " ", "\[Rho]"}]}], ")"}]}], "+", 
          RowBox[{"2", " ", "\[Rho]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "181"}], "+", 
             RowBox[{"27", " ", "\[Rho]"}]}], ")"}]}], "+", 
          RowBox[{"9", " ", 
           SuperscriptBox["\[Mu]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"39", "-", 
             RowBox[{"110", " ", "\[Rho]"}], "+", 
             RowBox[{"15", " ", 
              SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}], "+", 
          RowBox[{"\[Mu]", " ", 
           RowBox[{"(", 
            RowBox[{"358", "+", 
             RowBox[{"239", " ", "\[Rho]"}], "+", 
             RowBox[{"222", " ", 
              SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{
         SubscriptBox["q", "v"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}]}], "+", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"h", "[", 
       RowBox[{"x", ",", "t"}], "]"}], "6"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1632"}], "+", 
          RowBox[{"\[Mu]", " ", 
           RowBox[{"(", 
            RowBox[{"5359", "-", 
             RowBox[{"5625", " ", "\[Rho]"}]}], ")"}]}], "+", 
          RowBox[{"1877", " ", "\[Rho]"}], "-", 
          RowBox[{"126", " ", 
           SuperscriptBox["\[Rho]", "2"]}], "+", 
          RowBox[{"12", " ", 
           SuperscriptBox["\[Mu]", "3"], " ", 
           RowBox[{"(", 
            RowBox[{"2", "+", 
             RowBox[{"103", " ", "\[Rho]"}]}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["\[Mu]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "5239"}], "+", 
             RowBox[{"4294", " ", "\[Rho]"}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{
         SubscriptBox["q", "l"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"14", " ", "\[Rho]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "71"}], "+", 
             RowBox[{"9", " ", "\[Rho]"}]}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["\[Mu]", "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "819"}], "+", 
             RowBox[{"994", " ", "\[Rho]"}]}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["\[Mu]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"1279", "-", 
             RowBox[{"4419", " ", "\[Rho]"}], "+", 
             RowBox[{"270", " ", 
              SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}], "+", 
          RowBox[{"\[Mu]", " ", 
           RowBox[{"(", 
            RowBox[{"1600", "+", 
             RowBox[{"1237", " ", "\[Rho]"}], "+", 
             RowBox[{"558", " ", 
              SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{
         SubscriptBox["q", "v"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}]}]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"560", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "\[Rho]"}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"h", "[", 
        RowBox[{"x", ",", "t"}], "]"}]}], ")"}], "2"], " ", 
    SuperscriptBox[
     RowBox[{"h", "[", 
      RowBox[{"x", ",", "t"}], "]"}], "2"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "\[Mu]"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[Mu]"}], ")"}], " ", 
        RowBox[{"h", "[", 
         RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}], "3"]}], ")"}]}]], "Output",\
ExpressionUUID->"dc9eca22-d33e-4df1-8ef9-dad4069da0c2"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["In 2.24(c), ",
  FontFamily->"Arial",
  FontColor->RGBColor[1, 0, 0]],
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    OverscriptBox["M", "-"], "1"], TraditionalForm]],
  FontFamily->"Arial",
  FontColor->RGBColor[1, 0, 0],ExpressionUUID->
  "5e5bf15c-3181-49a6-a243-2ad7b4021718"],
 StyleBox[" is given by",
  FontFamily->"Arial",
  FontColor->RGBColor[1, 0, 0]]
}], "Subsection",
 CellFrame->{{0, 0}, {
   0, 0.5}},ExpressionUUID->"9e8f0848-77e7-40b3-a475-1dba6f937774"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"3", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"8", " ", 
       SuperscriptBox["\[Mu]", "4"], " ", 
       SuperscriptBox[
        RowBox[{
         SubscriptBox["q", "v"], "[", 
         RowBox[{"x", ",", "t"}], "]"}], "2"]}], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["\[Mu]", "3"], " ", 
       RowBox[{"h", "[", 
        RowBox[{"x", ",", "t"}], "]"}], " ", 
       RowBox[{
        SubscriptBox["q", "v"], "[", 
        RowBox[{"x", ",", "t"}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "\[Mu]", " ", 
          RowBox[{
           SubscriptBox["q", "l"], "[", 
           RowBox[{"x", ",", "t"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "22"}], "+", 
            RowBox[{"25", " ", "\[Mu]"}]}], ")"}], " ", 
          RowBox[{
           SubscriptBox["q", "v"], "[", 
           RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["\[Mu]", "2"], " ", 
       SuperscriptBox[
        RowBox[{"h", "[", 
         RowBox[{"x", ",", "t"}], "]"}], "2"], " ", 
       RowBox[{
        SubscriptBox["q", "v"], "[", 
        RowBox[{"x", ",", "t"}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "\[Mu]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "19"}], "+", 
            RowBox[{"28", " ", "\[Mu]"}]}], ")"}], " ", 
          RowBox[{
           SubscriptBox["q", "l"], "[", 
           RowBox[{"x", ",", "t"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"100", "+", 
            RowBox[{"273", " ", 
             SuperscriptBox["\[Mu]", "2"]}], "+", 
            RowBox[{"\[Mu]", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "555"}], "+", 
               RowBox[{"77", " ", "\[Rho]"}]}], ")"}]}]}], ")"}], " ", 
          RowBox[{
           SubscriptBox["q", "v"], "[", 
           RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[Mu]"}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"h", "[", 
         RowBox[{"x", ",", "t"}], "]"}], "10"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"48", "+", 
            RowBox[{"4", " ", 
             SuperscriptBox["\[Mu]", "2"]}], "+", 
            RowBox[{"16", " ", 
             SuperscriptBox["\[Mu]", "3"]}], "-", 
            RowBox[{"9", " ", "\[Rho]"}], "-", 
            RowBox[{"\[Mu]", " ", 
             RowBox[{"(", 
              RowBox[{"47", "+", 
               RowBox[{"12", " ", "\[Rho]"}]}], ")"}]}]}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{
            SubscriptBox["q", "l"], "[", 
            RowBox[{"x", ",", "t"}], "]"}], "2"]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", 
             SuperscriptBox["\[Mu]", "3"]}], "+", 
            RowBox[{"\[Mu]", " ", 
             RowBox[{"(", 
              RowBox[{"10", "-", 
               RowBox[{"13", " ", "\[Rho]"}]}], ")"}]}], "+", 
            RowBox[{
             SuperscriptBox["\[Mu]", "2"], " ", 
             RowBox[{"(", 
              RowBox[{"13", "-", 
               RowBox[{"10", " ", "\[Rho]"}]}], ")"}]}], "+", 
            RowBox[{"2", " ", "\[Rho]"}]}], ")"}], " ", 
          RowBox[{
           SubscriptBox["q", "l"], "[", 
           RowBox[{"x", ",", "t"}], "]"}], " ", 
          RowBox[{
           SubscriptBox["q", "v"], "[", 
           RowBox[{"x", ",", "t"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["\[Mu]", "3"], " ", 
             RowBox[{"(", 
              RowBox[{"9", "-", 
               RowBox[{"48", " ", "\[Rho]"}]}], ")"}]}], "-", 
            RowBox[{"16", " ", "\[Rho]"}], "-", 
            RowBox[{"4", " ", "\[Mu]", " ", "\[Rho]"}], "+", 
            RowBox[{
             SuperscriptBox["\[Mu]", "2"], " ", 
             RowBox[{"(", 
              RowBox[{"12", "+", 
               RowBox[{"47", " ", "\[Rho]"}]}], ")"}]}]}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{
            SubscriptBox["q", "v"], "[", 
            RowBox[{"x", ",", "t"}], "]"}], "2"]}]}], ")"}]}], "-", 
      RowBox[{
       SuperscriptBox["\[Mu]", "2"], " ", 
       SuperscriptBox[
        RowBox[{"h", "[", 
         RowBox[{"x", ",", "t"}], "]"}], "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"6", " ", "\[Mu]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"4", " ", "\[Mu]"}]}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{
            SubscriptBox["q", "l"], "[", 
            RowBox[{"x", ",", "t"}], "]"}], "2"]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{"28", "-", 
            RowBox[{"142", " ", "\[Mu]"}], "+", 
            RowBox[{"109", " ", 
             SuperscriptBox["\[Mu]", "2"]}]}], ")"}], " ", 
          RowBox[{
           SubscriptBox["q", "l"], "[", 
           RowBox[{"x", ",", "t"}], "]"}], " ", 
          RowBox[{
           SubscriptBox["q", "v"], "[", 
           RowBox[{"x", ",", "t"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"724", "-", 
            RowBox[{"217", " ", "\[Rho]"}], "+", 
            RowBox[{"44", " ", "\[Mu]", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "45"}], "+", 
               RowBox[{"14", " ", "\[Rho]"}]}], ")"}]}], "+", 
            RowBox[{
             SuperscriptBox["\[Mu]", "2"], " ", 
             RowBox[{"(", 
              RowBox[{"465", "+", 
               RowBox[{"96", " ", "\[Rho]"}]}], ")"}]}]}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{
            SubscriptBox["q", "v"], "[", 
            RowBox[{"x", ",", "t"}], "]"}], "2"]}]}], ")"}]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{"h", "[", 
         RowBox[{"x", ",", "t"}], "]"}], "9"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "144"}], "+", 
            RowBox[{"92", " ", 
             SuperscriptBox["\[Mu]", "3"]}], "+", 
            RowBox[{"56", " ", 
             SuperscriptBox["\[Mu]", "4"]}], "+", 
            RowBox[{"\[Mu]", " ", 
             RowBox[{"(", 
              RowBox[{"442", "-", 
               RowBox[{"6", " ", "\[Rho]"}]}], ")"}]}], "+", 
            RowBox[{"13", " ", "\[Rho]"}], "+", 
            RowBox[{
             SuperscriptBox["\[Mu]", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "467"}], "+", 
               RowBox[{"14", " ", "\[Rho]"}]}], ")"}]}]}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{
            SubscriptBox["q", "l"], "[", 
            RowBox[{"x", ",", "t"}], "]"}], "2"]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"14", " ", 
             SuperscriptBox["\[Mu]", "4"]}], "+", 
            RowBox[{"\[Mu]", " ", 
             RowBox[{"(", 
              RowBox[{"65", "-", 
               RowBox[{"67", " ", "\[Rho]"}]}], ")"}]}], "+", 
            RowBox[{"6", " ", "\[Rho]"}], "+", 
            RowBox[{"5", " ", 
             SuperscriptBox["\[Mu]", "2"], " ", 
             RowBox[{"(", 
              RowBox[{"5", "+", "\[Rho]"}], ")"}]}], "+", 
            RowBox[{
             SuperscriptBox["\[Mu]", "3"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "83"}], "+", 
               RowBox[{"35", " ", "\[Rho]"}]}], ")"}]}]}], ")"}], " ", 
          RowBox[{
           SubscriptBox["q", "l"], "[", 
           RowBox[{"x", ",", "t"}], "]"}], " ", 
          RowBox[{
           SubscriptBox["q", "v"], "[", 
           RowBox[{"x", ",", "t"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["\[Mu]", "4"], " ", 
             RowBox[{"(", 
              RowBox[{"77", "-", 
               RowBox[{"336", " ", "\[Rho]"}]}], ")"}]}], "+", 
            RowBox[{"104", " ", "\[Rho]"}], "-", 
            RowBox[{"212", " ", "\[Mu]", " ", "\[Rho]"}], "-", 
            RowBox[{
             SuperscriptBox["\[Mu]", "2"], " ", 
             RowBox[{"(", 
              RowBox[{"134", "+", 
               RowBox[{"43", " ", "\[Rho]"}]}], ")"}]}], "+", 
            RowBox[{"4", " ", 
             SuperscriptBox["\[Mu]", "3"], " ", 
             RowBox[{"(", 
              RowBox[{"9", "+", 
               RowBox[{"127", " ", "\[Rho]"}]}], ")"}]}]}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{
            SubscriptBox["q", "v"], "[", 
            RowBox[{"x", ",", "t"}], "]"}], "2"]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"h", "[", 
         RowBox[{"x", ",", "t"}], "]"}], "5"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "\[Mu]"}], " ", 
          RowBox[{"(", 
           RowBox[{"30", "+", 
            RowBox[{"381", " ", "\[Mu]"}], "-", 
            RowBox[{"940", " ", 
             SuperscriptBox["\[Mu]", "2"]}], "+", 
            RowBox[{"448", " ", 
             SuperscriptBox["\[Mu]", "3"]}]}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{
            SubscriptBox["q", "l"], "[", 
            RowBox[{"x", ",", "t"}], "]"}], "2"]}], "+", 
         RowBox[{"2", " ", "\[Mu]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "170"}], "-", 
            RowBox[{"329", " ", 
             SuperscriptBox["\[Mu]", "3"]}], "+", 
            RowBox[{"42", " ", "\[Rho]"}], "+", 
            RowBox[{"10", " ", 
             SuperscriptBox["\[Mu]", "2"], " ", 
             RowBox[{"(", 
              RowBox[{"77", "+", "\[Rho]"}], ")"}]}], "+", 
            RowBox[{"2", " ", "\[Mu]", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "179"}], "+", 
               RowBox[{"7", " ", "\[Rho]"}]}], ")"}]}]}], ")"}], " ", 
          RowBox[{
           SubscriptBox["q", "l"], "[", 
           RowBox[{"x", ",", "t"}], "]"}], " ", 
          RowBox[{
           SubscriptBox["q", "v"], "[", 
           RowBox[{"x", ",", "t"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["\[Mu]", "3"], " ", 
             RowBox[{"(", 
              RowBox[{"4746", "-", 
               RowBox[{"2560", " ", "\[Rho]"}]}], ")"}]}], "+", 
            RowBox[{"56", " ", "\[Rho]"}], "-", 
            RowBox[{"938", " ", "\[Mu]", " ", "\[Rho]"}], "-", 
            RowBox[{"21", " ", 
             SuperscriptBox["\[Mu]", "4"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "25"}], "+", 
               RowBox[{"96", " ", "\[Rho]"}]}], ")"}]}], "+", 
            RowBox[{"28", " ", 
             SuperscriptBox["\[Mu]", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "143"}], "+", 
               RowBox[{"147", " ", "\[Rho]"}]}], ")"}]}]}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{
            SubscriptBox["q", "v"], "[", 
            RowBox[{"x", ",", "t"}], "]"}], "2"]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"h", "[", 
         RowBox[{"x", ",", "t"}], "]"}], "6"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Mu]", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"1663", " ", "\[Mu]"}], "-", 
            RowBox[{"2056", " ", 
             SuperscriptBox["\[Mu]", "2"]}], "+", 
            RowBox[{"560", " ", 
             SuperscriptBox["\[Mu]", "3"]}], "-", 
            RowBox[{"21", " ", 
             RowBox[{"(", 
              RowBox[{"7", "+", 
               RowBox[{"3", " ", "\[Rho]"}]}], ")"}]}]}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{
            SubscriptBox["q", "l"], "[", 
            RowBox[{"x", ",", "t"}], "]"}], "2"]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"308", " ", 
             SuperscriptBox["\[Mu]", "4"]}], "+", 
            RowBox[{"\[Mu]", " ", 
             RowBox[{"(", 
              RowBox[{"400", "-", 
               RowBox[{"189", " ", "\[Rho]"}]}], ")"}]}], "+", 
            RowBox[{
             SuperscriptBox["\[Mu]", "2"], " ", 
             RowBox[{"(", 
              RowBox[{"468", "-", 
               RowBox[{"8", " ", "\[Rho]"}]}], ")"}]}], "+", 
            RowBox[{"7", " ", "\[Rho]"}], "-", 
            RowBox[{"5", " ", 
             SuperscriptBox["\[Mu]", "3"], " ", 
             RowBox[{"(", 
              RowBox[{"175", "+", 
               RowBox[{"4", " ", "\[Rho]"}]}], ")"}]}]}], ")"}], " ", 
          RowBox[{
           SubscriptBox["q", "l"], "[", 
           RowBox[{"x", ",", "t"}], "]"}], " ", 
          RowBox[{
           SubscriptBox["q", "v"], "[", 
           RowBox[{"x", ",", "t"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["\[Mu]", "2"], " ", 
             RowBox[{"(", 
              RowBox[{"4340", "-", 
               RowBox[{"5792", " ", "\[Rho]"}]}], ")"}]}], "-", 
            RowBox[{"280", " ", "\[Rho]"}], "+", 
            RowBox[{"2242", " ", "\[Mu]", " ", "\[Rho]"}], "+", 
            RowBox[{"105", " ", 
             SuperscriptBox["\[Mu]", "4"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "11"}], "+", 
               RowBox[{"32", " ", "\[Rho]"}]}], ")"}]}], "+", 
            RowBox[{"7", " ", 
             SuperscriptBox["\[Mu]", "3"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "513"}], "+", 
               RowBox[{"155", " ", "\[Rho]"}]}], ")"}]}]}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{
            SubscriptBox["q", "v"], "[", 
            RowBox[{"x", ",", "t"}], "]"}], "2"]}]}], ")"}]}], "+", 
      RowBox[{"\[Mu]", " ", 
       SuperscriptBox[
        RowBox[{"h", "[", 
         RowBox[{"x", ",", "t"}], "]"}], "4"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"6", " ", "\[Mu]", " ", 
          RowBox[{"(", 
           RowBox[{"3", "-", 
            RowBox[{"30", " ", "\[Mu]"}], "+", 
            RowBox[{"28", " ", 
             SuperscriptBox["\[Mu]", "2"]}]}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{
            SubscriptBox["q", "l"], "[", 
            RowBox[{"x", ",", "t"}], "]"}], "2"]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{"30", "-", 
            RowBox[{"441", " ", 
             SuperscriptBox["\[Mu]", "2"]}], "+", 
            RowBox[{"238", " ", 
             SuperscriptBox["\[Mu]", "3"]}], "+", 
            RowBox[{"\[Mu]", " ", 
             RowBox[{"(", 
              RowBox[{"153", "-", 
               RowBox[{"7", " ", "\[Rho]"}]}], ")"}]}]}], ")"}], " ", 
          RowBox[{
           SubscriptBox["q", "l"], "[", 
           RowBox[{"x", ",", "t"}], "]"}], " ", 
          RowBox[{
           SubscriptBox["q", "v"], "[", 
           RowBox[{"x", ",", "t"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"154", " ", "\[Rho]"}], "+", 
            RowBox[{"21", " ", 
             SuperscriptBox["\[Mu]", "3"], " ", 
             RowBox[{"(", 
              RowBox[{"11", "+", 
               RowBox[{"32", " ", "\[Rho]"}]}], ")"}]}], "-", 
            RowBox[{"21", " ", "\[Mu]", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "108"}], "+", 
               RowBox[{"71", " ", "\[Rho]"}]}], ")"}]}], "+", 
            RowBox[{"11", " ", 
             SuperscriptBox["\[Mu]", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "357"}], "+", 
               RowBox[{"169", " ", "\[Rho]"}]}], ")"}]}]}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{
            SubscriptBox["q", "v"], "[", 
            RowBox[{"x", ",", "t"}], "]"}], "2"]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"h", "[", 
         RowBox[{"x", ",", "t"}], "]"}], "7"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2214", " ", 
             SuperscriptBox["\[Mu]", "3"]}], "-", 
            RowBox[{"280", " ", 
             SuperscriptBox["\[Mu]", "4"]}], "-", 
            RowBox[{"3", " ", 
             RowBox[{"(", 
              RowBox[{"32", "+", 
               RowBox[{"7", " ", "\[Rho]"}]}], ")"}]}], "+", 
            RowBox[{"24", " ", "\[Mu]", " ", 
             RowBox[{"(", 
              RowBox[{"37", "+", 
               RowBox[{"7", " ", "\[Rho]"}]}], ")"}]}], "+", 
            RowBox[{
             SuperscriptBox["\[Mu]", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "2985"}], "+", 
               RowBox[{"76", " ", "\[Rho]"}]}], ")"}]}]}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{
            SubscriptBox["q", "l"], "[", 
            RowBox[{"x", ",", "t"}], "]"}], "2"]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"203", " ", 
             SuperscriptBox["\[Mu]", "4"]}], "+", 
            RowBox[{"\[Mu]", " ", 
             RowBox[{"(", 
              RowBox[{"500", "-", 
               RowBox[{"326", " ", "\[Rho]"}]}], ")"}]}], "-", 
            RowBox[{"4", " ", 
             SuperscriptBox["\[Mu]", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "93"}], "+", "\[Rho]"}], ")"}]}], "+", 
            RowBox[{"21", " ", "\[Rho]"}], "+", 
            RowBox[{
             SuperscriptBox["\[Mu]", "3"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "714"}], "+", 
               RowBox[{"20", " ", "\[Rho]"}]}], ")"}]}]}], ")"}], " ", 
          RowBox[{
           SubscriptBox["q", "l"], "[", 
           RowBox[{"x", ",", "t"}], "]"}], " ", 
          RowBox[{
           SubscriptBox["q", "v"], "[", 
           RowBox[{"x", ",", "t"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["\[Mu]", "4"], " ", 
             RowBox[{"(", 
              RowBox[{"1077", "-", 
               RowBox[{"3360", " ", "\[Rho]"}]}], ")"}]}], "+", 
            RowBox[{"536", " ", "\[Rho]"}], "-", 
            RowBox[{"2662", " ", "\[Mu]", " ", "\[Rho]"}], "+", 
            RowBox[{"16", " ", 
             SuperscriptBox["\[Mu]", "3"], " ", 
             RowBox[{"(", 
              RowBox[{"105", "+", 
               RowBox[{"83", " ", "\[Rho]"}]}], ")"}]}], "+", 
            RowBox[{"3", " ", 
             SuperscriptBox["\[Mu]", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "980"}], "+", 
               RowBox[{"1411", " ", "\[Rho]"}]}], ")"}]}]}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{
            SubscriptBox["q", "v"], "[", 
            RowBox[{"x", ",", "t"}], "]"}], "2"]}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"h", "[", 
         RowBox[{"x", ",", "t"}], "]"}], "8"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"1132", " ", 
              SuperscriptBox["\[Mu]", "3"]}], "+", 
             RowBox[{"56", " ", 
              SuperscriptBox["\[Mu]", "4"]}], "-", 
             RowBox[{"3", " ", 
              RowBox[{"(", 
               RowBox[{"96", "+", 
                RowBox[{"7", " ", "\[Rho]"}]}], ")"}]}], "+", 
             RowBox[{"\[Mu]", " ", 
              RowBox[{"(", 
               RowBox[{"1405", "+", 
                RowBox[{"87", " ", "\[Rho]"}]}], ")"}]}], "+", 
             RowBox[{
              SuperscriptBox["\[Mu]", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "2517"}], "+", 
                RowBox[{"128", " ", "\[Rho]"}]}], ")"}]}]}], ")"}]}], " ", 
          SuperscriptBox[
           RowBox[{
            SubscriptBox["q", "l"], "[", 
            RowBox[{"x", ",", "t"}], "]"}], "2"]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"94", " ", 
             SuperscriptBox["\[Mu]", "4"]}], "+", 
            RowBox[{"\[Mu]", " ", 
             RowBox[{"(", 
              RowBox[{"350", "-", 
               RowBox[{"283", " ", "\[Rho]"}]}], ")"}]}], "+", 
            RowBox[{"22", " ", "\[Rho]"}], "+", 
            RowBox[{
             SuperscriptBox["\[Mu]", "2"], " ", 
             RowBox[{"(", 
              RowBox[{"181", "+", "\[Rho]"}], ")"}]}], "+", 
            RowBox[{
             SuperscriptBox["\[Mu]", "3"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "427"}], "+", 
               RowBox[{"80", " ", "\[Rho]"}]}], ")"}]}]}], ")"}], " ", 
          RowBox[{
           SubscriptBox["q", "l"], "[", 
           RowBox[{"x", ",", "t"}], "]"}], " ", 
          RowBox[{
           SubscriptBox["q", "v"], "[", 
           RowBox[{"x", ",", "t"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["\[Mu]", "2"], " ", 
             RowBox[{"(", 
              RowBox[{"1204", "-", 
               RowBox[{"1299", " ", "\[Rho]"}]}], ")"}]}], "-", 
            RowBox[{"488", " ", "\[Rho]"}], "+", 
            RowBox[{"1604", " ", "\[Mu]", " ", "\[Rho]"}], "+", 
            RowBox[{"3", " ", 
             SuperscriptBox["\[Mu]", "4"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "185"}], "+", 
               RowBox[{"672", " ", "\[Rho]"}]}], ")"}]}], "-", 
            RowBox[{
             SuperscriptBox["\[Mu]", "3"], " ", 
             RowBox[{"(", 
              RowBox[{"465", "+", 
               RowBox[{"1999", " ", "\[Rho]"}]}], ")"}]}]}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{
            SubscriptBox["q", "v"], "[", 
            RowBox[{"x", ",", "t"}], "]"}], "2"]}]}], ")"}]}]}], ")"}]}], 
   ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"560", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"h", "[", 
        RowBox[{"x", ",", "t"}], "]"}]}], ")"}], "3"], " ", 
    SuperscriptBox[
     RowBox[{"h", "[", 
      RowBox[{"x", ",", "t"}], "]"}], "3"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"\[Mu]", "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[Mu]"}], ")"}], " ", 
        RowBox[{"h", "[", 
         RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}], "4"]}], ")"}]}]], "Output",\
ExpressionUUID->"4bda4e74-105c-4e7a-873b-517c68e348ef"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["In 2.24(c), ",
  FontFamily->"Arial",
  FontColor->RGBColor[1, 0, 0]],
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    OverscriptBox["V", "-"], "1"], TraditionalForm]],
  FontFamily->"Arial",
  FontColor->RGBColor[1, 0, 0],ExpressionUUID->
  "62ab1cc6-2e7a-4595-bf16-b4596c322834"],
 StyleBox[" is given by",
  FontFamily->"Arial",
  FontColor->RGBColor[1, 0, 0]]
}], "Subsection",
 CellFrame->{{0, 0}, {
   0, 0.5}},ExpressionUUID->"3941cdf7-7c1b-4264-ade4-37e4bb6b545c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox["\[Mu]", "2"]}], "+", 
    RowBox[{"\[Mu]", " ", 
     RowBox[{"(", 
      RowBox[{"4", "+", 
       RowBox[{"5", " ", "\[Mu]"}]}], ")"}], " ", 
     RowBox[{"h", "[", 
      RowBox[{"x", ",", "t"}], "]"}]}], "+", 
    RowBox[{"\[Mu]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "16"}], "-", 
       RowBox[{"15", " ", "\[Mu]"}], "+", 
       RowBox[{"25", " ", "\[Rho]"}]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"h", "[", 
       RowBox[{"x", ",", "t"}], "]"}], "2"]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Mu]", " ", 
        RowBox[{"(", 
         RowBox[{"24", "-", 
          RowBox[{"75", " ", "\[Rho]"}]}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox["\[Mu]", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"25", "-", 
          RowBox[{"32", " ", "\[Rho]"}]}], ")"}]}], "+", 
       RowBox[{"20", " ", "\[Rho]"}]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"h", "[", 
       RowBox[{"x", ",", "t"}], "]"}], "3"]}], "+", 
    RowBox[{"4", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "10"}], " ", "\[Rho]"}], "+", 
       RowBox[{"2", " ", "\[Mu]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "2"}], "+", 
          RowBox[{"5", " ", "\[Rho]"}]}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox["\[Mu]", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "5"}], "+", 
          RowBox[{"16", " ", "\[Rho]"}]}], ")"}]}]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"h", "[", 
       RowBox[{"x", ",", "t"}], "]"}], "4"]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[Mu]", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"6", "-", 
          RowBox[{"32", " ", "\[Rho]"}]}], ")"}]}], "+", 
       RowBox[{"12", " ", "\[Rho]"}], "+", 
       RowBox[{"2", " ", "\[Mu]", " ", 
        RowBox[{"(", 
         RowBox[{"2", "+", 
          RowBox[{"5", " ", "\[Rho]"}]}], ")"}]}]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"h", "[", 
       RowBox[{"x", ",", "t"}], "]"}], "5"]}]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"80", " ", 
    RowBox[{"h", "[", 
     RowBox[{"x", ",", "t"}], "]"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"\[Mu]", "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[Mu]"}], ")"}], " ", 
        RowBox[{"h", "[", 
         RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}], "2"]}], ")"}]}]], "Output",\
ExpressionUUID->"3c69282d-e0ef-4af8-a332-0e3fa80c5755"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["In 2.24(c), ",
  FontFamily->"Arial",
  FontColor->RGBColor[1, 0, 0]],
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    OverscriptBox["V", "-"], "2"], TraditionalForm]],
  FontFamily->"Arial",
  FontColor->RGBColor[1, 0, 0],ExpressionUUID->
  "de0bbfa0-6c21-459f-8c93-d11f9dd57e80"],
 StyleBox[" is given by",
  FontFamily->"Arial",
  FontColor->RGBColor[1, 0, 0]]
}], "Subsection",
 CellFrame->{{0, 0}, {
   0, 0.5}},ExpressionUUID->"8517350d-e18e-4401-a94b-6132e6ae888b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Mu]", "3"], " ", 
     RowBox[{"(", 
      RowBox[{"24", "-", 
       RowBox[{"17", " ", "\[Rho]"}]}], ")"}], " ", 
     RowBox[{
      SubscriptBox["q", "v"], "[", 
      RowBox[{"x", ",", "t"}], "]"}]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["\[Mu]", "2"], " ", 
     RowBox[{"h", "[", 
      RowBox[{"x", ",", "t"}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"9", " ", "\[Mu]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[Rho]"}], ")"}], " ", 
        RowBox[{
         SubscriptBox["q", "l"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"75", "+", 
          RowBox[{"96", " ", "\[Mu]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "\[Rho]"}], ")"}]}], "-", 
          RowBox[{"82", " ", "\[Rho]"}]}], ")"}], " ", 
        RowBox[{
         SubscriptBox["q", "v"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}]}], "-", 
    RowBox[{"\[Mu]", " ", 
     SuperscriptBox[
      RowBox[{"h", "[", 
       RowBox[{"x", ",", "t"}], "]"}], "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Mu]", " ", 
        RowBox[{"(", 
         RowBox[{"54", "-", 
          RowBox[{"47", " ", "\[Rho]"}], "+", 
          RowBox[{"14", " ", "\[Mu]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "9"}], "+", 
             RowBox[{"7", " ", "\[Rho]"}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{
         SubscriptBox["q", "l"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}], "+", 
       RowBox[{"7", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"8", " ", "\[Rho]"}], "+", 
          RowBox[{
           SuperscriptBox["\[Mu]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "78"}], "+", 
             RowBox[{"101", " ", "\[Rho]"}]}], ")"}]}], "+", 
          RowBox[{"\[Mu]", " ", 
           RowBox[{"(", 
            RowBox[{"150", "-", 
             RowBox[{"257", " ", "\[Rho]"}], "+", 
             RowBox[{"61", " ", 
              SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{
         SubscriptBox["q", "v"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox[
      RowBox[{"h", "[", 
       RowBox[{"x", ",", "t"}], "]"}], "8"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"12", " ", 
           SuperscriptBox["\[Mu]", "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{"8", " ", "\[Rho]"}]}], ")"}]}], "+", 
          RowBox[{"\[Rho]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "9"}], "+", 
             RowBox[{"16", " ", "\[Rho]"}]}], ")"}]}], "+", 
          RowBox[{"\[Mu]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "45"}], "+", 
             RowBox[{"191", " ", "\[Rho]"}], "-", 
             RowBox[{"76", " ", 
              SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}], "-", 
          RowBox[{
           SuperscriptBox["\[Mu]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"69", "+", 
             RowBox[{"26", " ", "\[Rho]"}], "+", 
             RowBox[{"66", " ", 
              SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{
         SubscriptBox["q", "l"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"4", " ", "\[Rho]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "46"}], "+", 
             RowBox[{"25", " ", "\[Rho]"}]}], ")"}]}], "+", 
          RowBox[{"\[Mu]", " ", "\[Rho]", " ", 
           RowBox[{"(", 
            RowBox[{"129", "+", 
             RowBox[{"32", " ", "\[Rho]"}]}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["\[Mu]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"75", "+", 
             RowBox[{"133", " ", "\[Rho]"}], "-", 
             RowBox[{"278", " ", 
              SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["\[Mu]", "3"], " ", 
           RowBox[{"(", 
            RowBox[{"51", "-", 
             RowBox[{"330", " ", "\[Rho]"}], "+", 
             RowBox[{"272", " ", 
              SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{
         SubscriptBox["q", "v"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}]}], "+", 
    RowBox[{"2", " ", "\[Mu]", " ", 
     SuperscriptBox[
      RowBox[{"h", "[", 
       RowBox[{"x", ",", "t"}], "]"}], "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"45", "+", 
          RowBox[{"84", " ", 
           SuperscriptBox["\[Mu]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "+", "\[Rho]"}], ")"}]}], "-", 
          RowBox[{"31", " ", "\[Rho]"}], "-", 
          RowBox[{"2", " ", "\[Mu]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "81"}], "+", 
             RowBox[{"74", " ", "\[Rho]"}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{
         SubscriptBox["q", "l"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"7", " ", 
           RowBox[{"(", 
            RowBox[{"89", "-", 
             RowBox[{"48", " ", "\[Rho]"}]}], ")"}], " ", "\[Rho]"}], "+", 
          RowBox[{"7", " ", "\[Mu]", " ", 
           RowBox[{"(", 
            RowBox[{"225", "-", 
             RowBox[{"520", " ", "\[Rho]"}], "+", 
             RowBox[{"183", " ", 
              SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["\[Mu]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "294"}], "+", 
             RowBox[{"295", " ", "\[Rho]"}], "+", 
             RowBox[{"272", " ", 
              SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{
         SubscriptBox["q", "v"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox[
      RowBox[{"h", "[", 
       RowBox[{"x", ",", "t"}], "]"}], "7"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Rho]", " ", 
           RowBox[{"(", 
            RowBox[{"47", "+", 
             RowBox[{"2", " ", "\[Rho]"}]}], ")"}]}], "+", 
          RowBox[{"14", " ", 
           SuperscriptBox["\[Mu]", "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "3"}], "+", 
             RowBox[{"29", " ", "\[Rho]"}]}], ")"}]}], "+", 
          RowBox[{"\[Mu]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "225"}], "+", 
             RowBox[{"538", " ", "\[Rho]"}], "-", 
             RowBox[{"257", " ", 
              SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["\[Mu]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "330"}], "+", 
             RowBox[{"31", " ", "\[Rho]"}], "-", 
             RowBox[{"170", " ", 
              SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{
         SubscriptBox["q", "l"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"4", " ", 
           RowBox[{"(", 
            RowBox[{"211", "-", 
             RowBox[{"134", " ", "\[Rho]"}]}], ")"}], " ", "\[Rho]"}], "+", 
          RowBox[{"\[Mu]", " ", "\[Rho]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1381"}], "+", 
             RowBox[{"562", " ", "\[Rho]"}]}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["\[Mu]", "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "282"}], "+", 
             RowBox[{"1649", " ", "\[Rho]"}], "-", 
             RowBox[{"1360", " ", 
              SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["\[Mu]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "525"}], "+", 
             RowBox[{"330", " ", "\[Rho]"}], "+", 
             RowBox[{"699", " ", 
              SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{
         SubscriptBox["q", "v"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}]}], "+", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"h", "[", 
       RowBox[{"x", ",", "t"}], "]"}], "4"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Mu]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "450"}], "+", 
          RowBox[{"373", " ", "\[Rho]"}], "-", 
          RowBox[{"63", " ", 
           SuperscriptBox["\[Rho]", "2"]}], "+", 
          RowBox[{"140", " ", 
           SuperscriptBox["\[Mu]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"3", "+", "\[Rho]"}], ")"}]}], "+", 
          RowBox[{"\[Mu]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "894"}], "+", 
             RowBox[{"824", " ", "\[Rho]"}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{
         SubscriptBox["q", "l"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"28", " ", "\[Rho]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "17"}], "+", 
             RowBox[{"12", " ", "\[Rho]"}]}], ")"}]}], "-", 
          RowBox[{"35", " ", "\[Mu]", " ", "\[Rho]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "154"}], "+", 
             RowBox[{"95", " ", "\[Rho]"}]}], ")"}]}], "+", 
          RowBox[{"5", " ", 
           SuperscriptBox["\[Mu]", "3"], " ", 
           RowBox[{"(", 
            RowBox[{"42", "-", 
             RowBox[{"425", " ", "\[Rho]"}], "+", 
             RowBox[{"544", " ", 
              SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["\[Mu]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"2625", "-", 
             RowBox[{"7072", " ", "\[Rho]"}], "+", 
             RowBox[{"2697", " ", 
              SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{
         SubscriptBox["q", "v"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox[
      RowBox[{"h", "[", 
       RowBox[{"x", ",", "t"}], "]"}], "5"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "14"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "+", "\[Rho]"}], ")"}], " ", "\[Rho]"}], "+", 
          RowBox[{"35", " ", 
           SuperscriptBox["\[Mu]", "3"], " ", 
           RowBox[{"(", 
            RowBox[{"3", "+", 
             RowBox[{"13", " ", "\[Rho]"}]}], ")"}]}], "+", 
          RowBox[{"\[Mu]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "450"}], "+", 
             RowBox[{"436", " ", "\[Rho]"}], "-", 
             RowBox[{"161", " ", 
              SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["\[Mu]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "708"}], "+", 
             RowBox[{"557", " ", "\[Rho]"}], "-", 
             RowBox[{"38", " ", 
              SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{
         SubscriptBox["q", "l"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Mu]", " ", 
           RowBox[{"(", 
            RowBox[{"4756", "-", 
             RowBox[{"2943", " ", "\[Rho]"}]}], ")"}], " ", "\[Rho]"}], "+", 
          RowBox[{"56", " ", "\[Rho]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "17"}], "+", 
             RowBox[{"12", " ", "\[Rho]"}]}], ")"}]}], "+", 
          RowBox[{"3", " ", 
           SuperscriptBox["\[Mu]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"875", "-", 
             RowBox[{"2336", " ", "\[Rho]"}], "+", 
             RowBox[{"754", " ", 
              SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["\[Mu]", "3"], " ", 
           RowBox[{"(", 
            RowBox[{"588", "-", 
             RowBox[{"3014", " ", "\[Rho]"}], "+", 
             RowBox[{"2720", " ", 
              SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{
         SubscriptBox["q", "v"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}]}], "+", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"h", "[", 
       RowBox[{"x", ",", "t"}], "]"}], "6"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"7", " ", 
           RowBox[{"(", 
            RowBox[{"24", "-", 
             RowBox[{"7", " ", "\[Rho]"}]}], ")"}], " ", "\[Rho]"}], "+", 
          RowBox[{"42", " ", 
           SuperscriptBox["\[Mu]", "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{"31", " ", "\[Rho]"}]}], ")"}]}], "+", 
          RowBox[{"\[Mu]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "900"}], "+", 
             RowBox[{"1255", " ", "\[Rho]"}], "-", 
             RowBox[{"621", " ", 
              SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["\[Mu]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1314"}], "+", 
             RowBox[{"653", " ", "\[Rho]"}], "-", 
             RowBox[{"284", " ", 
              SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{
         SubscriptBox["q", "l"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[Mu]", " ", 
           RowBox[{"(", 
            RowBox[{"7816", "-", 
             RowBox[{"4421", " ", "\[Rho]"}]}], ")"}], " ", "\[Rho]"}], "+", 
          RowBox[{"4", " ", "\[Rho]", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "687"}], "+", 
             RowBox[{"470", " ", "\[Rho]"}]}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["\[Mu]", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"3150", "-", 
             RowBox[{"6443", " ", "\[Rho]"}], "+", 
             RowBox[{"423", " ", 
              SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["\[Mu]", "3"], " ", 
           RowBox[{"(", 
            RowBox[{"1218", "-", 
             RowBox[{"6483", " ", "\[Rho]"}], "+", 
             RowBox[{"5440", " ", 
              SuperscriptBox["\[Rho]", "2"]}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{
         SubscriptBox["q", "v"], "[", 
         RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}]}]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"560", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "\[Rho]"}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"h", "[", 
        RowBox[{"x", ",", "t"}], "]"}]}], ")"}], "2"], " ", 
    SuperscriptBox[
     RowBox[{"h", "[", 
      RowBox[{"x", ",", "t"}], "]"}], "2"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "\[Mu]"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[Mu]"}], ")"}], " ", 
        RowBox[{"h", "[", 
         RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}], "3"]}], ")"}]}]], "Output",\
ExpressionUUID->"530c4a64-3a01-42a3-ba86-448019a2e523"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["In 2.24(d), ",
  FontFamily->"Arial",
  FontColor->RGBColor[1, 0, 0]],
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Gamma]", "1"], TraditionalForm]],
  FontFamily->"Arial",
  FontColor->RGBColor[1, 0, 0],ExpressionUUID->
  "cf8d8f41-8d1f-417a-a88a-c32a87b45e43"],
 StyleBox[" is given by",
  FontFamily->"Arial",
  FontColor->RGBColor[1, 0, 0]]
}], "Subsection",
 CellFrame->{{0, 0}, {
   0, 0.5}},ExpressionUUID->"467f05a2-a0a6-4f5d-9e90-3332f5c6af9e"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"h", "[", 
    RowBox[{"x", ",", "t"}], "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"\[Mu]", "-", 
        RowBox[{"\[Mu]", " ", 
         RowBox[{"h", "[", 
          RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}], " ", 
      SubscriptBox["Pr", "l"]}], "+", 
     RowBox[{"\[Kappa]", " ", "\[Rho]", " ", 
      RowBox[{"h", "[", 
       RowBox[{"x", ",", "t"}], "]"}], " ", 
      SubscriptBox["Pr", "v"]}]}], ")"}]}], 
  RowBox[{"3", " ", "\[Mu]", " ", 
   SubscriptBox["Pr", "v"]}]]], "Output",ExpressionUUID->"cac5b371-61fe-43d8-\
93e5-60739410bdbd"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["In 2.24(d), ",
  FontFamily->"Arial",
  FontColor->RGBColor[1, 0, 0]],
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Gamma]", "2"], TraditionalForm]],
  FontFamily->"Arial",
  FontColor->RGBColor[1, 0, 0],ExpressionUUID->
  "21a88985-10f0-4d98-848f-d298e3c54a5f"],
 StyleBox[" is given by",
  FontFamily->"Arial",
  FontColor->RGBColor[1, 0, 0]]
}], "Subsection",
 CellFrame->{{0, 0}, {
   0, 0.5}},ExpressionUUID->"0ccaedd9-b1cd-4002-a68d-72590db17283"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"20", " ", "\[Mu]", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"h", "[", 
       RowBox[{"x", ",", "t"}], "]"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "\[Mu]"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[Mu]"}], ")"}], " ", 
       RowBox[{"h", "[", 
        RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}], " ", 
    SubscriptBox["Pr", "v"]}]], 
  RowBox[{"3", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[Mu]", "2"], " ", 
      SubscriptBox["Pr", "l"], " ", 
      RowBox[{
       SubscriptBox["q", "v"], "[", 
       RowBox[{"x", ",", "t"}], "]"}]}], "+", 
     RowBox[{"\[Mu]", " ", 
      RowBox[{"h", "[", 
       RowBox[{"x", ",", "t"}], "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Mu]", " ", 
         SubscriptBox["Pr", "l"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            RowBox[{
             SubscriptBox["q", "l"], "[", 
             RowBox[{"x", ",", "t"}], "]"}]}], "-", 
           RowBox[{"3", " ", 
            RowBox[{
             SubscriptBox["q", "v"], "[", 
             RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}]}], "+", 
        RowBox[{"3", " ", "\[Kappa]", " ", "\[Rho]", " ", 
         SubscriptBox["Pr", "v"], " ", 
         RowBox[{
          SubscriptBox["q", "v"], "[", 
          RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}]}], "+", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"h", "[", 
        RowBox[{"x", ",", "t"}], "]"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "\[Kappa]", " ", 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{"3", " ", "\[Mu]"}]}], ")"}], " ", "\[Rho]", " ", 
         SubscriptBox["Pr", "v"], " ", 
         RowBox[{
          SubscriptBox["q", "v"], "[", 
          RowBox[{"x", ",", "t"}], "]"}]}], "+", 
        RowBox[{"\[Mu]", " ", 
         SubscriptBox["Pr", "l"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"3", "-", 
              RowBox[{"4", " ", "\[Mu]"}]}], ")"}], " ", 
            RowBox[{
             SubscriptBox["q", "l"], "[", 
             RowBox[{"x", ",", "t"}], "]"}]}], "+", 
           RowBox[{"3", " ", "\[Mu]", " ", 
            RowBox[{
             SubscriptBox["q", "v"], "[", 
             RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}]}]}], ")"}]}], "+", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"h", "[", 
        RowBox[{"x", ",", "t"}], "]"}], "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Mu]", " ", 
         SubscriptBox["Pr", "l"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "3"}], "+", 
              RowBox[{"2", " ", "\[Mu]"}]}], ")"}], " ", 
            RowBox[{
             SubscriptBox["q", "l"], "[", 
             RowBox[{"x", ",", "t"}], "]"}]}], "-", 
           RowBox[{"\[Mu]", " ", 
            RowBox[{
             SubscriptBox["q", "v"], "[", 
             RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}]}], "+", 
        RowBox[{"\[Kappa]", " ", "\[Rho]", " ", 
         SubscriptBox["Pr", "v"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SubscriptBox["q", "l"], "[", 
            RowBox[{"x", ",", "t"}], "]"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "2"}], "+", 
              RowBox[{"3", " ", "\[Mu]"}]}], ")"}], " ", 
            RowBox[{
             SubscriptBox["q", "v"], "[", 
             RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}]}]}], ")"}]}]}], 
    ")"}]}]}]], "Output",ExpressionUUID->"d7303154-2fb0-4cc5-a6cc-\
92b0076c313a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["In 2.24(d), ",
  FontFamily->"Arial",
  FontColor->RGBColor[1, 0, 0]],
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Gamma]", "3"], TraditionalForm]],
  FontFamily->"Arial",
  FontColor->RGBColor[1, 0, 0],ExpressionUUID->
  "326a0f38-7a36-4a28-8d10-8a15d63f3fea"],
 StyleBox[" is given by",
  FontFamily->"Arial",
  FontColor->RGBColor[1, 0, 0]]
}], "Subsection",
 CellFrame->{{0, 0}, {
   0, 0.5}},ExpressionUUID->"2565cc55-5be5-4ce5-9a46-94b826c89178"],

Cell[BoxData[
 RowBox[{"-", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"3", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["\[Mu]", "3"], " ", 
         SubscriptBox["Pr", "l"], " ", 
         RowBox[{"\[Theta]", "[", 
          RowBox[{"x", ",", "t"}], "]"}], " ", 
         RowBox[{
          SubscriptBox["q", "v"], "[", 
          RowBox[{"x", ",", "t"}], "]"}]}], "+", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{"2", " ", "\[Mu]"}]}], ")"}], " ", 
         SuperscriptBox["\[Mu]", "2"], " ", 
         RowBox[{"h", "[", 
          RowBox[{"x", ",", "t"}], "]"}], " ", 
         SubscriptBox["Pr", "l"], " ", 
         RowBox[{"\[Theta]", "[", 
          RowBox[{"x", ",", "t"}], "]"}], " ", 
         RowBox[{
          SubscriptBox["q", "v"], "[", 
          RowBox[{"x", ",", "t"}], "]"}]}], "+", 
        RowBox[{"2", " ", "\[Mu]", " ", 
         SuperscriptBox[
          RowBox[{"h", "[", 
           RowBox[{"x", ",", "t"}], "]"}], "3"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "\[Kappa]"}], " ", "\[Rho]", " ", 
            SubscriptBox["Pr", "v"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"\[Theta]", "[", 
               RowBox[{"x", ",", "t"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SubscriptBox["q", "l"], "[", 
               RowBox[{"x", ",", "t"}], "]"}], "+", 
              RowBox[{
               SubscriptBox["q", "v"], "[", 
               RowBox[{"x", ",", "t"}], "]"}]}], ")"}]}], "+", 
           RowBox[{"\[Mu]", " ", 
            SubscriptBox["Pr", "l"], " ", 
            RowBox[{"\[Theta]", "[", 
             RowBox[{"x", ",", "t"}], "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SubscriptBox["q", "l"], "[", 
               RowBox[{"x", ",", "t"}], "]"}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"3", "-", 
                 RowBox[{"2", " ", "\[Mu]"}]}], ")"}], " ", 
               RowBox[{
                SubscriptBox["q", "v"], "[", 
                RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}]}]}], ")"}]}], "+", 
        RowBox[{"\[Mu]", " ", 
         SuperscriptBox[
          RowBox[{"h", "[", 
           RowBox[{"x", ",", "t"}], "]"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[Kappa]", " ", "\[Rho]", " ", 
            SubscriptBox["Pr", "v"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"\[Theta]", "[", 
               RowBox[{"x", ",", "t"}], "]"}]}], ")"}], " ", 
            RowBox[{
             SubscriptBox["q", "v"], "[", 
             RowBox[{"x", ",", "t"}], "]"}]}], "+", 
           RowBox[{"\[Mu]", " ", 
            SubscriptBox["Pr", "l"], " ", 
            RowBox[{"\[Theta]", "[", 
             RowBox[{"x", ",", "t"}], "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               RowBox[{
                SubscriptBox["q", "l"], "[", 
                RowBox[{"x", ",", "t"}], "]"}]}], "+", 
              RowBox[{"6", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "\[Mu]"}], ")"}], " ", 
               RowBox[{
                SubscriptBox["q", "v"], "[", 
                RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}]}]}], ")"}]}], "+", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"h", "[", 
           RowBox[{"x", ",", "t"}], "]"}], "4"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["\[Mu]", "2"], " ", 
            SubscriptBox["Pr", "l"], " ", 
            RowBox[{"\[Theta]", "[", 
             RowBox[{"x", ",", "t"}], "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               RowBox[{
                SubscriptBox["q", "l"], "[", 
                RowBox[{"x", ",", "t"}], "]"}]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "2"}], "+", "\[Mu]"}], ")"}], " ", 
               RowBox[{
                SubscriptBox["q", "v"], "[", 
                RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}]}], "+", 
           RowBox[{"\[Kappa]", " ", "\[Rho]", " ", 
            SubscriptBox["Pr", "v"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"\[Theta]", "[", 
               RowBox[{"x", ",", "t"}], "]"}]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 RowBox[{"2", " ", "\[Mu]"}]}], ")"}], " ", 
               RowBox[{
                SubscriptBox["q", "l"], "[", 
                RowBox[{"x", ",", "t"}], "]"}]}], "+", 
              RowBox[{"\[Mu]", " ", 
               RowBox[{
                SubscriptBox["q", "v"], "[", 
                RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}]}]}], ")"}]}]}], 
       ")"}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"40", " ", "\[Mu]", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"h", "[", 
          RowBox[{"x", ",", "t"}], "]"}]}], ")"}], "2"], " ", 
      RowBox[{"h", "[", 
       RowBox[{"x", ",", "t"}], "]"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"\[Mu]", "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "\[Mu]"}], ")"}], " ", 
          RowBox[{"h", "[", 
           RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}], "2"], " ", 
      SubscriptBox["Pr", "v"]}], ")"}]}], ")"}]}]], "Output",ExpressionUUID->\
"f3e2647b-550c-4d9b-9c3f-204b130840e2"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["In 2.24(d), ",
  FontFamily->"Arial",
  FontColor->RGBColor[1, 0, 0]],
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Gamma]", "4"], TraditionalForm]],
  FontFamily->"Arial",
  FontColor->RGBColor[1, 0, 0],ExpressionUUID->
  "a6553661-88e3-4aa3-b547-8075988b11ed"],
 StyleBox[" is given by",
  FontFamily->"Arial",
  FontColor->RGBColor[1, 0, 0]]
}], "Subsection",
 CellFrame->{{0, 0}, {
   0, 0.5}},ExpressionUUID->"bce3cd3a-f5df-49cb-949a-81abe59ebcfa"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "9"}], " ", 
     SuperscriptBox["\[Mu]", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "\[Rho]"}], ")"}], " ", 
     SubscriptBox["Pr", "l"], " ", 
     RowBox[{"\[Theta]", "[", 
      RowBox[{"x", ",", "t"}], "]"}]}], "+", 
    RowBox[{"\[Mu]", " ", 
     RowBox[{"h", "[", 
      RowBox[{"x", ",", "t"}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "\[Kappa]"}], " ", "\[Rho]", " ", 
        RowBox[{"(", 
         RowBox[{"33", "+", 
          RowBox[{"7", " ", "\[Rho]"}]}], ")"}], " ", 
        SubscriptBox["Pr", "v"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"\[Theta]", "[", 
           RowBox[{"x", ",", "t"}], "]"}]}], ")"}]}], "+", 
       RowBox[{"18", " ", "\[Mu]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[Rho]"}], ")"}], " ", 
        SubscriptBox["Pr", "l"], " ", 
        RowBox[{"\[Theta]", "[", 
         RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}]}], "+", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"h", "[", 
       RowBox[{"x", ",", "t"}], "]"}], "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Kappa]", " ", "\[Rho]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "42"}], "+", 
          RowBox[{"33", " ", "\[Mu]"}], "+", 
          RowBox[{"2", " ", "\[Rho]"}], "+", 
          RowBox[{"7", " ", "\[Mu]", " ", "\[Rho]"}]}], ")"}], " ", 
        SubscriptBox["Pr", "v"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"\[Theta]", "[", 
           RowBox[{"x", ",", "t"}], "]"}]}], ")"}]}], "-", 
       RowBox[{"9", " ", 
        SuperscriptBox["\[Mu]", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "\[Rho]"}], ")"}], " ", 
        SubscriptBox["Pr", "l"], " ", 
        RowBox[{"\[Theta]", "[", 
         RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}]}]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"120", " ", "\[Mu]", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "\[Rho]"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "\[Mu]"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[Mu]"}], ")"}], " ", 
       RowBox[{"h", "[", 
        RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}], " ", 
    SubscriptBox["Pr", "v"]}], ")"}]}]], "Output",ExpressionUUID->"90a55f2d-\
9365-4bb4-bb39-1afd08d6a59f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["In 2.24(d), ",
  FontFamily->"Arial",
  FontColor->RGBColor[1, 0, 0]],
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Gamma]", "5"], TraditionalForm]],
  FontFamily->"Arial",
  FontColor->RGBColor[1, 0, 0],ExpressionUUID->
  "1f1ac491-e840-4ef4-a2ce-03ddefa6afc9"],
 StyleBox[" is given by",
  FontFamily->"Arial",
  FontColor->RGBColor[1, 0, 0]]
}], "Subsection",
 CellFrame->{{0, 0}, {
   0, 0.5}},ExpressionUUID->"ab650e95-0ec9-4009-afad-4227272057fd"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"h", "[", 
     RowBox[{"x", ",", "t"}], "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"\[Kappa]", " ", "\[Rho]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"40", " ", "\[Mu]"}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"40", "-", 
            RowBox[{"80", " ", "\[Mu]"}]}], ")"}], " ", 
          RowBox[{"h", "[", 
           RowBox[{"x", ",", "t"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "49"}], "+", 
            RowBox[{"40", " ", "\[Mu]"}], "+", 
            RowBox[{"9", " ", "\[Rho]"}]}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{"h", "[", 
            RowBox[{"x", ",", "t"}], "]"}], "2"]}]}], ")"}], " ", 
       SubscriptBox["Pr", "v"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"\[Theta]", "[", 
          RowBox[{"x", ",", "t"}], "]"}]}], ")"}]}], "-", 
      RowBox[{"\[Mu]", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"h", "[", 
          RowBox[{"x", ",", "t"}], "]"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Mu]", " ", 
          RowBox[{"(", 
           RowBox[{"2", "-", 
            RowBox[{"42", " ", "\[Rho]"}]}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "7"}], "-", 
            RowBox[{"33", " ", "\[Rho]"}], "+", 
            RowBox[{"\[Mu]", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "2"}], "+", 
               RowBox[{"42", " ", "\[Rho]"}]}], ")"}]}]}], ")"}], " ", 
          RowBox[{"h", "[", 
           RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}], " ", 
       SubscriptBox["Pr", "l"], " ", 
       RowBox[{"\[Theta]", "[", 
        RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{"120", " ", "\[Mu]", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "\[Rho]"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"h", "[", 
       RowBox[{"x", ",", "t"}], "]"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "\[Mu]"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "\[Mu]"}], ")"}], " ", 
       RowBox[{"h", "[", 
        RowBox[{"x", ",", "t"}], "]"}]}]}], ")"}], " ", 
    SubscriptBox["Pr", "v"]}], ")"}]}]], "Output",ExpressionUUID->"5bf554a3-\
2842-4faf-a3da-1012b10ecc83"],

Cell["", "Text",
 Selectable->False,
 CellFrame->{{0, 0}, {0, 3}},
 ShowCellBracket->False,
 CellMargins->{{0, 0}, {1, 1}},
 CellElementSpacings->{"CellMinHeight"->1},
 CellFrameMargins->0,
 CellFrameColor->RGBColor[0, 0, 1],
 CellSize->{
  Inherited, 5},ExpressionUUID->"b5e96a1c-0376-4dee-9185-09cdf8b7ca70"]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1366, 685},
WindowMargins->{{-8, Automatic}, {Automatic, -8}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
TrackCellChangeTimes->False,
Magnification:>0.85 Inherited,
FrontEndVersion->"11.2 for Microsoft Windows (64-bit) (September 10, 2017)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 324, 5, 128, "Chapter",ExpressionUUID->"76777feb-d6a4-4243-8fc3-5177d5598087"],
Cell[907, 29, 248, 3, 43, "Subsection",ExpressionUUID->"9a895c91-e008-4438-b3a5-eb47dd57c306"],
Cell[CellGroupData[{
Cell[1180, 36, 432, 12, 41, "Subsection",ExpressionUUID->"68c09f61-8233-46f7-9e67-026523da3020"],
Cell[1615, 50, 4193, 127, 59, "Output",ExpressionUUID->"9ce02677-ff42-4a38-94ad-2f12b9e314ec"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5845, 182, 432, 12, 54, "Subsection",ExpressionUUID->"de5d189b-2499-4e19-8092-7297255a24f8"],
Cell[6280, 196, 6369, 194, 83, "Output",ExpressionUUID->"d9f3610c-d1cf-4b96-944b-b77795f721d7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12686, 395, 435, 14, 54, "Subsection",ExpressionUUID->"d85df040-6907-48d7-ba53-881939363ceb"],
Cell[13124, 411, 1011, 32, 52, "Output",ExpressionUUID->"34990140-33d0-478e-971e-15b9b875e135"]
}, Open  ]],
Cell[CellGroupData[{
Cell[14172, 448, 434, 14, 54, "Subsection",ExpressionUUID->"d204a984-97d0-4949-a9e4-ca5226e36acf"],
Cell[14609, 464, 1545, 51, 52, "Output",ExpressionUUID->"57420244-b119-4e35-afa7-2ca7b3938777"]
}, Open  ]],
Cell[CellGroupData[{
Cell[16191, 520, 366, 11, 54, "Subsection",ExpressionUUID->"4f7de890-0f87-4f4c-9d15-2e0a6776d6f8"],
Cell[16560, 533, 913, 30, 49, "Output",ExpressionUUID->"7bfb2096-f4ea-48ba-9493-a4cf65ce6483"]
}, Open  ]],
Cell[CellGroupData[{
Cell[17510, 568, 366, 11, 54, "Subsection",ExpressionUUID->"7aa7a771-7bad-4419-af48-b2ef31a698b2"],
Cell[17879, 581, 1004, 34, 52, "Output",ExpressionUUID->"6025b525-fcf9-435f-abe2-668dcd6751bc"]
}, Open  ]],
Cell[CellGroupData[{
Cell[18920, 620, 434, 14, 54, "Subsection",ExpressionUUID->"d4407e63-658e-42f5-ae3d-bf117496b394"],
Cell[19357, 636, 859, 27, 52, "Output",ExpressionUUID->"6de8cb7c-3c28-4868-b993-b3cefc59e5f9"]
}, Open  ]],
Cell[CellGroupData[{
Cell[20253, 668, 434, 14, 54, "Subsection",ExpressionUUID->"cb600586-8e4d-4aec-b1be-e4c3de119293"],
Cell[20690, 684, 1241, 42, 52, "Output",ExpressionUUID->"04a83d58-7bb8-4845-af7f-581ab47f27ca"]
}, Open  ]],
Cell[CellGroupData[{
Cell[21968, 731, 366, 11, 54, "Subsection",ExpressionUUID->"7ab022b9-f037-4754-9185-c19362cac0b2"],
Cell[22337, 744, 1000, 32, 46, "Output",ExpressionUUID->"d1ee7812-a2d5-469e-a4a0-9f6e7492b909"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23374, 781, 366, 11, 54, "Subsection",ExpressionUUID->"40c081c1-dfc4-4fd6-9992-1c57bda31112"],
Cell[23743, 794, 1001, 34, 52, "Output",ExpressionUUID->"f8c06807-fb8c-49cf-94c2-3ad98a4c91f9"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24781, 833, 409, 12, 57, "Subsection",ExpressionUUID->"44f398ad-97e1-414d-a16c-092489e95714"],
Cell[25193, 847, 324, 10, 46, "Output",ExpressionUUID->"92b8cce3-c492-4764-bf1c-3a4167de4ac9"]
}, Open  ]],
Cell[CellGroupData[{
Cell[25554, 862, 409, 12, 57, "Subsection",ExpressionUUID->"ff2a021e-b3c4-4554-a299-bb37d718202a"],
Cell[25966, 876, 522, 18, 46, "Output",ExpressionUUID->"797b8807-7bdc-436c-acb8-733760d6db12"]
}, Open  ]],
Cell[CellGroupData[{
Cell[26525, 899, 396, 12, 57, "Subsection",ExpressionUUID->"227dbb67-cf59-4e98-8728-ab305bd1c2cc"],
Cell[26924, 913, 83, 0, 27, "Output",ExpressionUUID->"2b3f8789-22dd-4151-bbf9-5d1f2daa115e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[27044, 918, 396, 12, 57, "Subsection",ExpressionUUID->"4fc977b0-d3c8-492e-9b6c-8d4c20980a0f"],
Cell[27443, 932, 508, 18, 46, "Output",ExpressionUUID->"d90c9a31-1b3c-4791-a245-f1da288ef42f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[27988, 955, 473, 15, 51, "Subsection",ExpressionUUID->"d3908f0f-f7e4-4f84-9c4c-10789e1d1a2b"],
Cell[28464, 972, 2322, 74, 35, "Output",ExpressionUUID->"236becdf-1c63-48f0-a625-65499fc7cf74"]
}, Open  ]],
Cell[CellGroupData[{
Cell[30823, 1051, 473, 15, 51, "Subsection",ExpressionUUID->"10249f40-872c-408c-8ec7-41b6c2c12ffe"],
Cell[31299, 1068, 13892, 403, 203, "Output",ExpressionUUID->"fd81c091-8777-40b3-b926-95ff979ee343"]
}, Open  ]],
Cell[CellGroupData[{
Cell[45228, 1476, 473, 15, 51, "Subsection",ExpressionUUID->"83ded633-b232-4ecd-b18e-a5d97a616080"],
Cell[45704, 1493, 23304, 610, 299, "Output",ExpressionUUID->"d9545587-8182-4b88-aadd-a795cadaf8e4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[69045, 2108, 487, 15, 51, "Subsection",ExpressionUUID->"067faa09-973f-4d30-9525-42608b017e60"],
Cell[69535, 2125, 2577, 82, 59, "Output",ExpressionUUID->"2a750f5a-8baa-4f22-b38d-a4c4a4d8c9a1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[72149, 2212, 473, 15, 51, "Subsection",ExpressionUUID->"4f160a1f-f540-4570-83f8-5bbd47ea56b4"],
Cell[72625, 2229, 15756, 450, 227, "Output",ExpressionUUID->"9fcb7bfa-1cd2-48be-b9cf-1955550c07b8"]
}, Open  ]],
Cell[CellGroupData[{
Cell[88418, 2684, 498, 16, 57, "Subsection",ExpressionUUID->"4baae16c-8b01-428e-872e-2eaf6a7a9fc3"],
Cell[88919, 2702, 2422, 77, 35, "Output",ExpressionUUID->"89178cba-7b54-43da-874e-4d22829ae62a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[91378, 2784, 498, 16, 57, "Subsection",ExpressionUUID->"c04b2262-7f24-4aa0-bbe4-31f77b62eec8"],
Cell[91879, 2802, 14288, 413, 203, "Output",ExpressionUUID->"dc9eca22-d33e-4df1-8ef9-dad4069da0c2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[106204, 3220, 498, 16, 57, "Subsection",ExpressionUUID->"9e8f0848-77e7-40b3-a475-1dba6f937774"],
Cell[106705, 3238, 23324, 640, 299, "Output",ExpressionUUID->"4bda4e74-105c-4e7a-873b-517c68e348ef"]
}, Open  ]],
Cell[CellGroupData[{
Cell[130066, 3883, 498, 16, 57, "Subsection",ExpressionUUID->"3941cdf7-7c1b-4264-ade4-37e4bb6b545c"],
Cell[130567, 3901, 2676, 85, 59, "Output",ExpressionUUID->"3c69282d-e0ef-4af8-a332-0e3fa80c5755"]
}, Open  ]],
Cell[CellGroupData[{
Cell[133280, 3991, 498, 16, 57, "Subsection",ExpressionUUID->"8517350d-e18e-4401-a94b-6132e6ae888b"],
Cell[133781, 4009, 16313, 465, 203, "Output",ExpressionUUID->"530c4a64-3a01-42a3-ba86-448019a2e523"]
}, Open  ]],
Cell[CellGroupData[{
Cell[150131, 4479, 480, 15, 51, "Subsection",ExpressionUUID->"467f05a2-a0a6-4f5d-9e90-3332f5c6af9e"],
Cell[150614, 4496, 648, 20, 46, "Output",ExpressionUUID->"cac5b371-61fe-43d8-93e5-60739410bdbd"]
}, Open  ]],
Cell[CellGroupData[{
Cell[151299, 4521, 480, 15, 51, "Subsection",ExpressionUUID->"0ccaedd9-b1cd-4002-a68d-72590db17283"],
Cell[151782, 4538, 3880, 117, 72, "Output",ExpressionUUID->"d7303154-2fb0-4cc5-a6cc-92b0076c313a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[155699, 4660, 480, 15, 51, "Subsection",ExpressionUUID->"2565cc55-5be5-4ce5-9a46-94b826c89178"],
Cell[156182, 4677, 6028, 166, 79, "Output",ExpressionUUID->"f3e2647b-550c-4d9b-9c3f-204b130840e2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[162247, 4848, 480, 15, 51, "Subsection",ExpressionUUID->"bce3cd3a-f5df-49cb-949a-81abe59ebcfa"],
Cell[162730, 4865, 2597, 78, 52, "Output",ExpressionUUID->"90a55f2d-9365-4bb4-bb39-1afd08d6a59f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[165364, 4948, 480, 15, 51, "Subsection",ExpressionUUID->"ab650e95-0ec9-4009-afad-4227272057fd"],
Cell[165847, 4965, 2622, 80, 52, "Output",ExpressionUUID->"5bf554a3-2842-4faf-a3da-1012b10ecc83"],
Cell[168472, 5047, 310, 9, 9, "Text",ExpressionUUID->"b5e96a1c-0376-4dee-9185-09cdf8b7ca70"]
}, Open  ]]
}, Open  ]]
}
]
*)

